@@ -10,15 +10,13 @@ use File::HomeDir;
 use Log::Any qw/$log/;
 use Path::Tiny qw/path rootdir cwd/;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 our $pager;
 
 sub DBVERSION { 1 }
 sub MSWin32   { $^O eq 'MSWin32' }
 
-has debug => (
-    is => 'rw',
-);
+has debug => ( is => 'rw', );
 
 has db => (
     is      => 'ro',
@@ -124,7 +122,7 @@ sub BUILD {
     binmode STDIN,  ':encoding(utf8)';
     binmode STDOUT, ':encoding(utf8)';
 
-    if ($self->debug($self->debug // $opts->{debug})) {
+    if ( $self->debug( $self->debug // $opts->{debug} ) ) {
         require Log::Any::Adapter;
         if ( exists $INC{'Test/More.pm'} ) {
 
@@ -238,8 +236,7 @@ sub _build_user_db {
     my $dsn = 'dbi:SQLite:dbname=' . $file;
 
     require Bif::DB;
-    my $db =
-      Bif::DB->connect( $dsn, undef, undef, undef, $self->opts->{debug} );
+    my $db = Bif::DB->connect( $dsn, undef, undef, undef, $self->debug );
 
     $log->debug( 'bif: user_db: ' . $dsn );
     $log->debug( 'bif: SQLite version: ' . $db->{sqlite_version} );
@@ -257,8 +254,7 @@ sub _build_user_dbw {
     my $dsn = 'dbi:SQLite:dbname=' . $file;
 
     require Bif::DBW;
-    my $dbw =
-      Bif::DBW->connect( $dsn, undef, undef, undef, $self->opts->{debug} );
+    my $dbw = Bif::DBW->connect( $dsn, undef, undef, undef, $self->debug );
 
     $log->debug( 'bif: user_dbw: ' . $dsn );
     $log->debug( 'bif: SQLite version: ' . $dbw->{sqlite_version} );
@@ -276,8 +272,7 @@ sub _build_db {
     my $dsn = 'dbi:SQLite:dbname=' . $file;
 
     require Bif::DB;
-    my $db =
-      Bif::DB->connect( $dsn, undef, undef, undef, $self->opts->{debug} );
+    my $db = Bif::DB->connect( $dsn, undef, undef, undef, $self->debug );
 
     $log->debug( 'bif: db: ' . $dsn );
     $log->debug( 'bif: SQLite version: ' . $db->{sqlite_version} );
@@ -295,8 +290,7 @@ sub _build_dbw {
     my $dsn = 'dbi:SQLite:dbname=' . $file;
 
     require Bif::DBW;
-    my $dbw =
-      Bif::DBW->connect( $dsn, undef, undef, undef, $self->opts->{debug} );
+    my $dbw = Bif::DBW->connect( $dsn, undef, undef, undef, $self->debug );
 
     $log->debug( 'bif: dbw: ' . $dsn );
     $log->debug( 'bif: SQLite version: ' . $dbw->{sqlite_version} );
@@ -373,7 +367,7 @@ sub find_repo {
         if ( -d ( my $repo = $try->child($name) ) ) {
             return $repo;
         }
-        elsif ( -f $repo ) { # inside a repo directory
+        elsif ( -f $repo ) {    # inside a repo directory
             return $try;
         }
         last if $try->is_rootdir;
@@ -501,7 +495,7 @@ sub ctime_ago {
     return (
         Time::Duration::ago( $row->{ctime_age}, 1 ),
         Time::Piece->strptime( $row->{ctime} + $row->{ctimetz}, '%s' )
-          ->strftime('%a %F %R ') . $row->{ctimetzhm}
+          ->strftime('%a %Y-%m-%d %H:%M ') . $row->{ctimetzhm}
     );
 }
 
@@ -517,7 +511,7 @@ sub mtime_ago {
     return (
         Time::Duration::ago( $row->{mtime_age}, 1 ),
         Time::Piece->strptime( $row->{mtime} + $row->{mtimetz}, '%s' )
-          ->strftime('%a %F %R ') . $row->{mtimetzhm}
+          ->strftime('%a %Y-%m-%d %H:%M ') . $row->{mtimetzhm}
     );
 }
 
@@ -625,39 +619,8 @@ sub get_project {
 
 sub get_hub {
     my $self = shift;
-    my $name = shift;
-    my $db   = $self->db;
-
-    if ( $name =~ m/^(\d+)$/ ) {
-        return $db->xhashref(
-            select     => [qw/h.id p.name t.kind t.uuid t.first_change_id/],
-            from       => 'hubs h',
-            inner_join => 'projects p',
-            on         => 'p.id = h.id',
-            inner_join => 'topics t',
-            on         => 't.id = h.id',
-            where      => { 'h.id' => $name },
-        );
-    }
-
-    my ($hub) = $db->xhashref(
-        select           => [qw/h.id p.name t.kind t.uuid t.first_change_id/],
-        from             => 'hubs h',
-        inner_join       => 'projects p',
-        on               => 'p.id = h.id',
-        inner_join       => 'topics t',
-        on               => 't.id = h.id',
-        where            => { 'p.name' => $self->uuid2id($name) },
-        union_all_select => [qw/h.id p.name t.kind t.uuid t.first_change_id/],
-        from             => 'hub_repos hr',
-        inner_join       => 'hubs h',
-        on               => 'h.id = hr.hub_id',
-        inner_join       => 'topics t',
-        on               => 't.id = h.id',
-        inner_join       => 'projects p',
-        on               => 'p.id = h.id',
-        where            => { 'hr.location' => $name },
-    );
+    my $name = shift;                       # || Carp::confess 'get_hub($name)';
+    my $hub  = $self->db->get_hub($name);
 
     return $self->err( 'HubNotFound', "hub not found: $name" )
       unless $hub;
@@ -836,17 +799,15 @@ sub current_work {
     my $self = shift;
     return $self->dbw->xhashref(
         select => [
-            't.id AS id',
+            't.id AS topic_id',
             't.kind AS kind',
-            'tp.path AS path',
+            't.path AS path',
             'wb.start AS start',
             'wb.billable AS billable',
         ],
         from       => 'work_buffers wb',
         inner_join => 'topics t',
         on         => 't.id = wb.topic_id',
-        inner_join => 'topic_path tp',
-        on         => 'tp.id = t.id',
         where      => { 'wb.stop' => undef },
     );
 }
@@ -872,7 +833,7 @@ sub start_work {
     return $self->dbw->xdo(
         insert_into => 'work_buffers',
         values      => {
-            topic_id      => $args->{id},
+            topic_id      => $args->{topic_id},
             start         => $args->{start},
             start_comment => $args->{start_comment},
             stop          => $args->{stop},
@@ -886,6 +847,59 @@ sub stop_work {
     my $self = shift;
     my $args = {@_};
     my $dbw  = $self->dbw;
+    my $ref  = $dbw->xhashref(
+        select => '*',
+        from   => 'work_buffers',
+        where  => { stop => undef },
+    );
+
+    $self->work_buffer($ref) if $ref and $args->{save};
+
+    if ($ref) {
+
+        # We are currently working something so we need to check if the
+        # start time is yesterday (for some kind of yesterday) and
+        # insert (multiple) work buffers that don't cross the midnight
+        # boundary.
+
+        # The trick is that the calculation has to be done in the
+        # timezone of the $ref work buffer. The code below is probably
+        # broken if the current timezone offste is different to
+        # $ref->{offset}.
+
+        state $have_time_piece   = require Time::Piece;
+        state $have_time_seconds = require Time::Seconds;
+
+        my $stop_ymd =
+          Time::Piece->gmtime( $args->{stop} + $ref->{offset} )->ymd;
+        my $boundary =
+          Time::Piece->strptime(
+            Time::Piece->gmtime( $ref->{start} + $ref->{offset} )->ymd,
+            '%Y-%m-%d' ) +
+          Time::Seconds->ONE_DAY - 1;
+
+        until ( $boundary->ymd eq $stop_ymd ) {
+            $dbw->xdo(
+                update => 'work_buffers',
+                set    => { stop => $boundary->epoch - $ref->{offset} },
+                where  => { stop => undef },
+            );
+
+            $self->dbw->xdo(
+                insert_into => 'work_buffers',
+                values      => {
+                    topic_id      => $ref->{topic_id},
+                    start         => ( $boundary - $ref->{offset} + 1 )->epoch,
+                    start_comment => $ref->{start_comment},
+                    stop          => undef,
+                    stop_comment  => $ref->{stop_comment},
+                    billable      => $ref->{billable},
+                },
+            );
+
+            $boundary = $boundary + Time::Seconds->ONE_DAY;
+        }
+    }
 
     $dbw->xdo(
         update => 'work_buffers',
@@ -896,19 +910,53 @@ sub stop_work {
         where => { stop => undef },
     );
 
-    if ( $args->{restore} and my $ref = $self->work_buffer ) {
+    if ( $args->{restore} and my $saved = $self->work_buffer ) {
 
         $self->start_work(
-            id            => $ref->{topic_id},
+            topic_id      => $saved->{topic_id},
+            offset        => $saved->{offset},
             start         => $args->{stop},
-            start_comment => $ref->{start_comment},
-            billable      => $ref->{billable},
+            start_comment => $saved->{start_comment},
+            billable      => $saved->{billable},
         );
 
         $self->work_buffer(undef);
     }
 }
 
+sub save_work {
+    my $self = shift;
+    my $args = {@_};
+
+    $self->dbw->xdo(
+        insert_into => [
+            'func_new_work', qw/change_id topic_id offset start stop
+              start_comment stop_comment/
+        ],
+        select => [
+            $args->{change_id}, $args->{topic_id},
+            'wb.offset',        'wb.start',
+            'wb.stop',          'wb.start_comment',
+            'wb.stop_comment',
+        ],
+        from  => 'work_buffers wb',
+        where => {
+            'wb.topic_id' => $args->{topic_id},
+            'wb.billable' => 1,
+            'wb.stop !'   => undef,
+        },
+    );
+
+    $self->dbw->xdo(
+        delete_from => 'work_buffers',
+        where       => {
+            'topic_id' => $args->{topic_id},
+            'billable' => 1,
+            'stop !'   => undef,
+        }
+    );
+}
+
 sub new_change {
     my $self = shift;
     my %vals = @_;
@@ -1090,7 +1138,7 @@ App::bif - A base class for App::bif::* commands
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
@@ -1351,7 +1399,7 @@ Returns a hashref representing the currently open work buffer:
 
 =over
 
-=item * id
+=item * topic_id
 
 =item * kind
 
@@ -1369,7 +1417,7 @@ Creates a new entry in the work_buffers table.
 
 =over
 
-=item * id
+=item * topic_id
 
 =item * start
 
@@ -1381,13 +1429,14 @@ Creates a new entry in the work_buffers table.
 
 =item * billable
 
-=item * restore
+=item * save
 
 =back
 
 =item stop_work(%opts)
 
-Finalizes an open entry in the work_buffers table.
+Ensures nothing is worked, finalizing an open entry in the work_buffers
+table if one exists.
 
 =over
 
@@ -1395,6 +1444,8 @@ Finalizes an open entry in the work_buffers table.
 
 =item * stop_comment
 
+=item * restore
+
 =item * save
 
 =back
