@@ -1,6 +1,6 @@
 package App::bif::OptArgs;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 
 package    # do a little hiding
   App::bif;
@@ -80,20 +80,15 @@ subcmd(
     comment => 'initialize a new repository',
 );
 
-arg name => (
-    isa     => 'Str',
-    comment => 'name of new hub',
-);
-
 opt keep_invalid => (
     isa     => 'Bool',
     comment => 'Keep invalid updates in the database',
     hidden  => 1,
 );
 
-arg location => (
+arg directory => (
     isa     => 'Str',
-    comment => 'location of new remote hub',
+    comment => 'hub location',
 );
 
 opt debug_bifsync => (
@@ -189,16 +184,15 @@ arg name => (
     comment => 'name of organisation\'s hub',
 );
 
-arg title => (
+arg location => (
     isa     => 'Str',
-    comment => 'title of organisation\'s hub',
+    comment => 'hub location',
 );
 
-arg locations => (
-    isa     => 'ArrayRef',
-    default => [],
+arg title => (
+    isa     => 'Str',
     greedy  => 1,
-    comment => 'hub locations',
+    comment => 'title of organisation\'s hub',
 );
 
 opt default => (
@@ -492,12 +486,6 @@ arg status => (
     comment => 'limit the list by status type(s)',
 );
 
-opt hub => (
-    isa     => 'Str',
-    alias   => 'H',
-    comment => 'Limit the list to projects located at HUB',
-);
-
 opt local => (
     isa     => 'Bool',
     alias   => 'l',
@@ -711,6 +699,12 @@ arg date => (
     comment => 'timesheet start date',
 );
 
+opt identity => (
+    isa     => 'Str',
+    alias   => 'i',
+    comment => 'alternative identity instead of self',
+);
+
 opt number => (
     isa     => 'Int',
     alias   => 'n',
@@ -1262,8 +1256,7 @@ subcmd(
 );
 
 arg path => (
-    isa      => 'ArrayRef',
-    greedy   => 1,
+    isa      => 'Str',
     required => 1,
     comment  => 'path(s) of the project(s) to be imported',
 );
@@ -1275,6 +1268,11 @@ opt debug_bifsync => (
     hidden  => 1,
 );
 
+opt hub => (
+    isa     => 'Str',
+    comment => 'a specific hub to pull from',
+);
+
 # ------------------------------------------------------------------------
 # pull provider
 # ------------------------------------------------------------------------
@@ -1366,16 +1364,15 @@ subcmd(
 );
 
 arg path => (
-    isa      => 'ArrayRef',
+    isa      => 'Str',
     required => 1,
-    greedy   => 1,
-    comment  => 'path(s) of the project(s) to be exported',
+    comment  => 'path of the project to export',
 );
 
 arg hub => (
     isa      => 'Str',
     required => 1,
-    comment  => 'destination hub address or alias',
+    comment  => 'destination location URI',
 );
 
 opt debug_bifsync => (
@@ -1509,6 +1506,12 @@ subcmd(
     comment => 'review entries in the work buffer',
 );
 
+opt identity => (
+    isa     => 'Str',
+    alias   => 'i',
+    comment => 'alternative identity instead of self',
+);
+
 opt long => (
     isa     => 'Bool',
     alias   => 'l',
@@ -1574,7 +1577,7 @@ App::bif::OptArgs - bif command argument & option definitions
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
