@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use DBIx::ThinSQL qw/sq/;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub run {
@@ -22,20 +22,24 @@ sub run {
 
     $dbw->txn(
         sub {
-            $opts->{change_id} = $self->new_change;
+            $self->start_work(
+                start         => time,
+                start_comment => "drop hub $info->{name} <$uuid>",
+                billable      => 0,
+                save          => 1,
+            );
 
             $dbw->xdo(
                 delete_from => 'hubs',
                 where       => { id => $info->{id} },
             );
 
-            $self->end_change(
-                id            => $opts->{change_id},
-                action_format => "drop hub $info->{name} ($info->{id})",
-                message       => "    [  Dropped Hub:        ]\n"
-                  . "    [    Name: $info->{name}  ]",
-            );
+            print "Hub dropped: $info->{name} <$uuid>\n",
 
+              $self->stop_work(
+                stop    => time,
+                restore => 1,
+              );
         }
     );
 
@@ -53,7 +57,7 @@ bif-drop-hub - remove an hub from the repository
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
