@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub run {
@@ -21,20 +21,24 @@ sub run {
 
     $dbw->txn(
         sub {
-            $opts->{change_id} = $self->new_change;
+            $self->start_work(
+                start         => time,
+                start_comment => "drop issue $info->{id} <$uuid>",
+                billable      => 0,
+                save          => 1,
+            );
 
             $dbw->xdo(
                 delete_from => 'issues',
                 where       => { id => $info->{id} },
             );
 
-            $self->end_change(
-                id            => $opts->{change_id},
-                action_format => "drop issue $info->{id} <$uuid>",
-                message       => "    [  Dropped Issue:        ]\n"
-                  . "    [    ID: $info->{id}  ]",
-            );
+            print "Issue dropped: $info->{id} <$uuid>\n",
 
+              $self->stop_work(
+                stop    => time,
+                restore => 1,
+              );
         }
     );
 
@@ -52,7 +56,7 @@ bif-drop-issue - remove an issue from the repository
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
