@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use Path::Tiny qw/cwd path/;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub init_user_repo {
@@ -42,7 +42,19 @@ sub init_user_repo {
 sub run {
     my $self = shift;
     my $opts = $self->opts;
-    my $dir  = cwd->child( $opts->{name} ? $opts->{name} . '.bif' : '.bif' );
+
+    my $dir;
+    my $name;
+    if ( $opts->{directory} ) {
+        $opts->{directory} .= '.bifhub'
+          unless $opts->{directory} =~ m/\.bifhub$/;
+        $dir  = path( $opts->{directory} );
+        $name = $dir->basename;
+        $dir  = $dir->parent->realpath->child($name);
+    }
+    else {
+        $dir = cwd->child('.bif');
+    }
 
     return $self->err( 'DirExists', 'directory exists: ' . $dir )
       if -e $dir;
@@ -78,16 +90,17 @@ sub run {
             $self->new_cmd(
                 'App::bif::new::hub',
                 opts => {
-                    name      => $opts->{name},
-                    title     => $opts->{name},
-                    locations => [ $opts->{location} || $dir ],
-                    default   => 1,
+                    name     => $name,
+                    title    => $opts->{title} || $name,
+                    location => $dir,
+                    default  => 1,
                 }
               )->run
-              if $opts->{name};
+              if $opts->{directory};
         },
     )->run;
 
+    return $self->ok('InitHub') if $opts->{directory};
     return $self->ok('Init');
 }
 
@@ -102,22 +115,22 @@ bif-init - initialize a new bif repository
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
-    bif init [NAME] [LOCATION] [OPTIONS...]
+    bif init [DIRECTORY] [OPTIONS...]
 
 =head1 DESCRIPTION
 
 The B<bif-init> command initializes a repository ready for use by other
-bif commands. The repository type - Working, Local Hub, or Remote Hub -
-depends on the arguments given. In addition, a special User repository
-will always be created if it doesn't exist.
+bif commands.  In addition, a special User repository will always be
+created if it doesn't exist.
 
-All of the work is actually performed by other commands. They are
-wrapped by B<bif-init> in order to simplify common initialization
-scenarios, each of which is described in more detail below.
+All of the B<bif-init> work is actually performed by other commands.
+They are wrapped by B<bif-init> in order to simplify common
+initialization scenarios, each of which is described in more detail
+below.
 
 =head2 User Repository
 
@@ -181,13 +194,13 @@ take place.
 
 =head2 Local Hub Repository
 
-When the NAME argument is given on its own a I<local> hub repository is
-initialized in F<NAME.bif>.
+When the DIRECTORY argument is given on its own a I<local> hub
+repository is initialized in F<DIRECTORY.bifhub>.
 
 =for bifcode #!sh
 
     bif init myhub
-    # Creating repository: myhub.bif (v323)
+    # Creating repository: myhub.bifhub (v323)
     # Importing identity ($HOME/.bifu): received: 1/1
     # Hub created: myhub
 
@@ -201,7 +214,7 @@ For the above case the individual steps would look something like this:
     bif new repo $DIR
     cd $DIR
     bif pull identity $USER_REPO --self
-    bif new hub $NAME $DIR --default
+    bif new hub $BASENAME $DIRECTORY
     cd ..
 
 =end comment
@@ -213,16 +226,16 @@ is used to "register" a local hub with the current working repository:
 
 =for bifcode #!sh
     
-    bif pull hub myhub.bif
-    # myhub.bif: received: 2/2
+    bif pull hub myhub.bifhub
+    # myhub.bifhub: received: 2/2
     # Hub pulled: myhub
 
 =head2 Remote Hub Repository
 
-Initializing a I<remote> hub repository can only be performed from a
-previously initialized working repository. It also requires that you
-have registered with a hub provider and have signed up for a hosting
-plan.
+Initializing a I<remote> hub repository is actually done with the
+L<bif-new-hub> command, but must be performed from a previously
+initialized working repository. It also requires that you have
+registered with a hub provider and have signed up for a hosting plan.
 
 =for bifcode #!sh
 
@@ -241,13 +254,9 @@ the LOCATION.
 
 =over
 
-=item NAME
+=item DIRECTORY
 
-The name of a new hub repository
-
-=item LOCATION
-
-The location of a new I<remote> hub repository.
+The location a local hub repository to initialize.
 
 =item --keep-invalid
 
@@ -283,7 +292,7 @@ Default user repository location.
 
 =head1 SEE ALSO
 
-L<bif>(1)
+L<bif>(1), L<bif-new-hub>
 
 =head1 AUTHOR
 
