@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use Term::ANSIColor qw/color/;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub run {
@@ -15,30 +15,19 @@ sub run {
     DBIx::ThinSQL->import(qw/ qv concat/);
 
     my $data = $db->xarrayrefs(
-        select => [
-            qw/t.kind h.id p.path/,
-            'COALESCE(hr.location,"") AS location',
-            'COUNT(p.id) AS project_count',
-        ],
+        select     => [ 't.kind', 'h.id', 't.path', 'h.location', ],
         from       => 'hubs h',
-        inner_join => 'projects p',
-        on         => 'p.id = h.id',
         inner_join => 'topics t',
         on         => 't.id = h.id',
-        left_join  => 'hub_repos hr',
-        on         => 'hr.id = h.default_repo_id',
-        left_join  => 'projects p2',
-        on         => 'p2.hub_id = h.id',
-        group_by   => [qw/t.kind h.id p.name location/],
-        order_by   => 'p.name',
+        order_by => [ 't.path', 'h.location' ],
     );
 
     return $self->ok('ListHubs') unless $data;
 
     $self->start_pager( scalar @$data );
 
-    print $self->render_table( ' l r  l  l  r ',
-        [ 'Type', 'ID', 'Name', 'Location', 'Projects' ], $data );
+    print $self->render_table( ' l r  l  l ',
+        [ 'Type', 'ID', 'Path', 'Location' ], $data );
 
     return $self->ok('ListHubs');
 }
@@ -54,7 +43,7 @@ bif-list-hubs - list hubs registered with current repository
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
