@@ -4,7 +4,7 @@ use warnings;
 use utf8;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub run {
@@ -15,8 +15,10 @@ sub run {
     DBIx::ThinSQL->import(qw/ qv concat coalesce/);
 
     my @projects = $db->xarrayrefs(
-        select => [ 'projects.id', 'projects.path', 0 ],
-        from   => 'projects',
+        select     => [ 'p.id', 't.path', 0 ],
+        from       => 'projects p',
+        inner_join => 'topics t',
+        on         => 't.id = p.id',
 
         #        inner_join => 'project_status',
         #        on         => [
@@ -24,7 +26,7 @@ sub run {
         #            'project_status.status = ',
         #            qv('active')
         #        ],
-        order_by => 'projects.path',
+        order_by => 't.path',
     );
 
     require Text::FormatTable;
@@ -96,7 +98,7 @@ bif-list-issues - list projects' issues
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
