@@ -6,7 +6,7 @@ use Bif::Mo;
 use DBIx::ThinSQL qw/ qv case concat coalesce sq/;
 use Time::Duration qw/concise duration/;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub run {
@@ -15,8 +15,10 @@ sub run {
     my $db   = $self->db;
 
     my @projects = $db->xarrayrefs(
-        select => [ 'p.id', 'p.path', 'p.hub_id' ],
-        from   => 'projects p',
+        select     => [ 'p.id', 't.path', 'p.default_hub_id' ],
+        from       => 'projects p',
+        inner_join => 'topics t',
+        on         => 't.id = p.id',
         do {
 
             if ( $opts->{project_status} ) {
@@ -32,9 +34,7 @@ sub run {
                 ();
             }
         },
-        left_join => 'hubs h',
-        on        => 'h.id = p.hub_id',
-        order_by  => 'path',
+        order_by => 't.path',
     );
 
     return $self->ok('ListTopics') unless @projects;
@@ -165,7 +165,7 @@ bif-list-topics - list projects' tasks and issues
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
