@@ -11,7 +11,7 @@ use Time::Duration qw/ago/;
 use Time::Piece;
 use Time::Seconds;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub run {
@@ -72,11 +72,11 @@ sub run_by_full {
         ),
         select => [
             '"c" || c.id AS change_id',
-            'p.path AS project',
+            't.path AS path',
             'COALESCE(c.author,e.name) AS author',
             "COALESCE(c.author_contact_method || ': ' || c.author_contact,"
               . "ecm.method || ': ' || ecm.mvalue) AS contact",
-            'COALESCE(iss.title, t.title) AS title',
+            'COALESCE(iss.title, ta.title) AS title',
             'c.uuid AS change_uuid',
             'c.action',
             'c.mtime',
@@ -91,7 +91,10 @@ sub run_by_full {
                     when => 'b.start',
                     then => qv( $yellow . ' [+]' . $reset ),
                     else => qv(''),
-                )
+                ),
+                qv(' '),
+                't.path'
+
             )->as('action'),
         ],
         from       => 'changes c',
@@ -105,18 +108,18 @@ sub run_by_full {
         on         => 'i.id = c.identity_id',
         left_join  => 'b',
         on         => 'c.id BETWEEN b.start+1 AND b.stop',
-        left_join  => 'tasks t',
-        on         => 't.id = cd.action_topic_id_1',
+        left_join  => 'tasks ta',
+        on         => 'ta.id = cd.action_topic_id_1',
         left_join  => 'task_status ts',
-        on         => 'ts.id = t.task_status_id',
+        on         => 'ts.id = ta.task_status_id',
         left_join  => 'issues iss',
         on         => 'iss.id = cd.action_topic_id_1',
         left_join  => 'topics tp',
-        on         => 'tp.id = t.id',
+        on         => 'tp.id = ta.id',
         left_join  => 'projects p',
         on         => 'p.id = ts.project_id OR p.id = cd.action_topic_id_1',
-        left_join  => 'hubs h',
-        on         => 'h.id = p.hub_id',
+        left_join  => 'topics t',
+        on         => 't.id = c.action_topic_id_1',
         order_by   => \@order,
     );
 
@@ -194,9 +197,10 @@ sub run_by_time {
     );
 
     my $localtime = localtime();
-    my $today     = $localtime->strftime('%F');
+    my $today     = $localtime->strftime('%Y-%m-%d');
     my $yesterday =
-      ( $localtime - ONE_HOUR * ( $localtime->hour + 12 ) )->strftime('%F');
+      ( $localtime - ONE_HOUR * ( $localtime->hour + 12 ) )
+      ->strftime('%Y-%m-%d');
 
     my $mdate = '';
     my $table = Text::FormatTable->new(' l  l  l  l ');
@@ -283,8 +287,6 @@ sub run_by_id {
         on         => 'ts.id = t.task_status_id',
         left_join  => 'projects p',
         on         => 'p.id = ts.project_id OR p.id = cd.action_topic_id_1',
-        left_join  => 'hubs h',
-        on         => 'h.id = p.hub_id',
         order_by   => ['c.id DESC'],
     );
 
@@ -498,7 +500,7 @@ bif-log - review the repository or topic history
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
