@@ -4,7 +4,7 @@ use warnings;
 use feature 'state';
 use Bif::Mo;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif::log';
 
 sub run {
@@ -52,7 +52,7 @@ sub run {
         left_join  => 'projects',
         on         => 'projects.id = task_status.project_id',
         left_join  => 'hubs h',
-        on         => 'h.id = projects.hub_id',
+        on         => 'h.id = projects.default_hub_id',
         inner_join => 'changes_tree',
         on         => {
             'changes_tree.parent' => $info->{first_change_id},
@@ -89,7 +89,7 @@ bif-log-task - review a task history
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
