@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use IO::Prompt::Tiny qw/prompt/;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub run {
@@ -12,31 +12,54 @@ sub run {
     my $opts = $self->opts;
     my $dbw  = $self->dbw;
 
-    $opts->{name} ||= prompt( 'Name:', '' )
-      || return $self->err( 'NameRequired', 'name is required' );
-
-    $opts->{title} ||= prompt( 'Title:', '' )
-      || return $self->err( 'TitleRequired', 'title is required' );
-
-    $opts->{message} ||= "New hub $opts->{name}";
-
     $dbw->txn(
         sub {
+            my $start = time;
+            $self->stop_work(
+                stop => $start,
+                save => 1,
+            );
+
+            $opts->{name} ||= prompt( 'Name:', '' )
+              || return $self->err( 'NameRequired', 'name is required' );
+
+            $opts->{location} ||= prompt( 'Location:', '' )
+              || return $self->err( 'LocationRequired',
+                'location is required' );
+
+            $opts->{title}   ||= $opts->{name};
+            $opts->{message} ||= "New hub $opts->{name}";
             $opts->{id}        = $dbw->nextval('topics');
             $opts->{change_id} = $self->new_change;
 
             $self->new_hub;
 
-            my $path = $dbw->xval(
-                select => 'path',
-                from   => 'topic_path tp',
-                where  => { 'tp.id' => $opts->{id} },
+            $dbw->xdo(
+                insert_into => 'bifkv',
+                values      => { key => 'local', hub_id => $opts->{id} },
+            ) if $opts->{default};
+
+            $self->start_work(
+                topic_id      => $opts->{id},
+                start         => $start,
+                start_comment => "new hub",
+                billable      => 1,
+            );
+
+            $self->stop_work(
+                stop    => time,
+                restore => 1,
+            );
+
+            $self->save_work(
+                topic_id  => $opts->{id},
+                change_id => $opts->{change_id}
             );
 
             $self->end_change(
                 id                => $opts->{change_id},
                 message           => $opts->{message},
-                action_format     => "new hub $path (%s)",
+                action_format     => "new hub $opts->{name} (%s)",
                 action_topic_id_1 => $opts->{id},
             );
 
@@ -66,37 +89,12 @@ sub new_hub {
     $dbw->xdo(
         insert_into => 'func_new_hub',
         values      => {
-            change_id   => $opts->{change_id},
-            id          => $opts->{id},
-            set_default => $opts->{default},
+            change_id => $opts->{change_id},
+            id        => $opts->{id},
+            location  => $opts->{location},
         },
     );
 
-    my $i = 0;
-    foreach my $location ( @{ $opts->{locations} } ) {
-        my $rid = $dbw->nextval('topics');
-
-        $dbw->xdo(
-            insert_into => 'func_new_hub_repo',
-            values      => {
-                id        => $rid,
-                change_id => $opts->{change_id},
-                hub_id    => $opts->{id},
-                location  => $location,
-            },
-        );
-
-        $dbw->xdo(
-            update => 'hubs',
-            set    => {
-                default_repo_id => $rid,
-            },
-            where => {
-                id => $opts->{id},
-            },
-        ) unless $i++;
-    }
-
     return 1;
 }
 
@@ -111,7 +109,7 @@ bif-new-hub - create a new hub in the repository
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
