@@ -7,50 +7,58 @@ use DBIx::ThinSQL qw/bv/;
 use IO::Prompt::Tiny qw/prompt/;
 use Path::Tiny qw/path/;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub run {
-    my $self   = shift;
-    my $opts   = $self->opts;
-    my $dbw    = $self->dbw;
-    my $name   = '';
-    my $email  = '';
-    my $spacer = '';
-
-    if ( $opts->{self} ) {
-        print "Creating \"self\" identity:\n";
-
-        my $git_conf_file = path( File::HomeDir->my_home, '.gitconfig' );
-        my $git_conf = Config::Tiny->read($git_conf_file) || {};
-
-        $name  = $git_conf->{user}->{name}  || 'Your Name';
-        $email = $git_conf->{user}->{email} || 'your@email.adddr';
-
-        $name =~ s/(^")|("$)//g;
-        $email =~ s/(^")|("$)//g;
-
-        $spacer = '  ';
-    }
-
-    $opts->{name} ||= prompt( $spacer . 'Name:', $name )
-      || return $self->err( 'NameRequired', 'name is required' );
-
-    my $short = join( '', $opts->{name} =~ m/(\b\w)/g );
-    $opts->{shortname} ||= prompt( $spacer . 'Short Name:', $short )
-      || return $self->err( 'NameRequired', 'shortname is required' );
-
-    $opts->{method} ||= prompt( $spacer . 'Contact Method:', 'email' )
-      || return $self->err( 'MethodRequired', 'method is required' );
-
-    $opts->{value} ||=
-      prompt( $spacer . 'Contact ' . ucfirst( $opts->{method} ) . ':', $email )
-      || return $self->err( 'ValueRequired', 'value is required' );
-
-    $opts->{message} ||= '';
+    my $self = shift;
+    my $opts = $self->opts;
+    my $dbw  = $self->dbw;
 
     $dbw->txn(
         sub {
+            my $start = time;
+            $self->stop_work(
+                stop => $start,
+                save => 1,
+            );
+
+            my $name   = '';
+            my $email  = '';
+            my $spacer = '';
+
+            if ( $opts->{self} ) {
+                print "Creating \"self\" identity:\n";
+
+                my $git_conf_file =
+                  path( File::HomeDir->my_home, '.gitconfig' );
+                my $git_conf = Config::Tiny->read($git_conf_file) || {};
+
+                $name  = $git_conf->{user}->{name}  || 'Your Name';
+                $email = $git_conf->{user}->{email} || 'your@email.adddr';
+
+                $name =~ s/(^")|("$)//g;
+                $email =~ s/(^")|("$)//g;
+
+                $spacer = '  ';
+            }
+
+            $opts->{name} ||= prompt( $spacer . 'Name:', $name )
+              || return $self->err( 'NameRequired', 'name is required' );
+
+            my $short = join( '', $opts->{name} =~ m/(\b\w)/g );
+            $opts->{shortname} ||= prompt( $spacer . 'Short Name:', $short )
+              || return $self->err( 'NameRequired', 'shortname is required' );
+
+            $opts->{method} ||= prompt( $spacer . 'Contact Method:', 'email' )
+              || return $self->err( 'MethodRequired', 'method is required' );
+
+            $opts->{value} ||=
+              prompt( $spacer . 'Contact ' . ucfirst( $opts->{method} ) . ':',
+                $email )
+              || return $self->err( 'ValueRequired', 'value is required' );
+
+            $opts->{message} ||= '';
             $opts->{id}     = $dbw->nextval('topics');
             $opts->{ecm_id} = $dbw->nextval('topics');
 
@@ -98,16 +106,27 @@ sub run {
                 },
             );
 
-            my $path = $dbw->xval(
-                select => 'path',
-                from   => 'topic_path tp',
-                where  => { 'tp.id' => $opts->{id} },
+            $self->start_work(
+                topic_id      => $opts->{id},
+                start         => $start,
+                start_comment => "new identity",
+                billable      => 1,
+            );
+
+            $self->stop_work(
+                stop    => time,
+                restore => 1,
+            );
+
+            $self->save_work(
+                topic_id  => $opts->{id},
+                change_id => $opts->{change_id}
             );
 
             $self->end_change(
                 id            => $opts->{change_id},
                 message       => $opts->{message},
-                action_format => "new identity %s ($path), "
+                action_format => "new identity %s "
                   . "$opts->{name} ($opts->{shortname})",
                 action_topic_id_1 => $opts->{id},
             );
@@ -128,7 +147,7 @@ bif-new-identity - create a new identity in the repository
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
