@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use IO::Prompt::Tiny qw/prompt/;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub run {
@@ -12,54 +12,65 @@ sub run {
     my $opts = $self->opts;
     my $dbw  = $self->dbw;
 
-    $opts->{title} ||= prompt( 'Title:', '' )
-      || return $self->err( 'TitleRequired', 'title is required' );
+    $dbw->txn(
+        sub {
+            my $start = time;
+            $self->stop_work(
+                stop => $start,
+                save => 1,
+            );
 
-    if ( !$opts->{path} ) {
+            $opts->{title} ||= prompt( 'Title:', '' )
+              || return $self->err( 'TitleRequired', 'title is required' );
 
-        my @paths = $dbw->xarrayrefs(
-            select    => 'p.path',
-            from      => 'projects p',
-            left_join => 'hubs h',
-            on        => 'h.id = p.hub_id',
-            order_by  => 'path',
-        );
+            if ( !$opts->{path} ) {
 
-        if ( 0 == @paths ) {
-            return $self->err( 'NoProjectInRepo', 'task needs a project' );
-        }
-        elsif ( 1 == @paths ) {
-            $opts->{path} = $paths[0]->[0];
-        }
-        else {
-            $opts->{path} = prompt( 'Project:', $paths[0]->[0] )
-              || return $self->err( 'ProjectRequired', 'project is required' );
-        }
-    }
+                my @paths = $dbw->xarrayrefs(
+                    select     => 't.path',
+                    from       => 'projects p',
+                    inner_join => 'topics t',
+                    on         => 't.id = p.id',
+                    order_by =>
+                      [ 't.kind = "project" DESC', 'p.local DESC', 't.path', ],
+                );
 
-    my $pinfo = $self->get_project( $opts->{path} );
+                if ( 0 == @paths ) {
+                    return $self->err( 'NoProjectInRepo',
+                        'task needs a project' );
+                }
+                elsif ( 1 == @paths ) {
+                    $opts->{path} = $paths[0]->[0];
+                }
+                else {
+                    $opts->{path} = prompt( 'Project:', $paths[0]->[0] )
+                      || return $self->err( 'ProjectRequired',
+                        'project is required' );
+                }
+            }
 
-    if ( $opts->{status} ) {
-        my ( $status_ids, $invalid ) =
-          $dbw->status_ids( $pinfo->{id}, 'issue', $opts->{status} );
+            my $pinfo = $self->get_project( $opts->{path} );
 
-        return $self->err( 'InvalidStatus',
-            'unknown status: ' . join( ', ', @$invalid ) )
-          if @$invalid;
+            if ( $opts->{status} ) {
+                my ( $status_ids, $invalid ) =
+                  $dbw->status_ids( $pinfo->{id}, 'issue', $opts->{status} );
 
-        $opts->{issue_status_id} = $status_ids->[0];
-    }
-    else {
-        $opts->{issue_status_id} = $dbw->xval(
-            select => 'id',
-            from   => 'issue_status',
-            where  => { project_id => $pinfo->{id}, def => 1 },
-        );
-    }
+                return $self->err( 'InvalidStatus',
+                    'unknown status: ' . join( ', ', @$invalid ) )
+                  if @$invalid;
 
-    $opts->{message} ||= $self->prompt_edit(
-        opts => $self,
-        txt  => "
+                $opts->{issue_status_id} = $status_ids->[0];
+            }
+            else {
+                $opts->{issue_status_id} = $dbw->xval(
+                    select => 'id',
+                    from   => 'issue_status',
+                    where  => { project_id => $pinfo->{id}, def => 1 },
+                );
+            }
+
+            $opts->{message} ||= $self->prompt_edit(
+                opts => $self,
+                txt  => "
 
 # Things to keep in mind when reporting a software issue:
 #
@@ -73,9 +84,7 @@ sub run {
 #
 #   - What (output) actually occured?
 #"
-    );
-    $dbw->txn(
-        sub {
+            );
             $opts->{id}        = $dbw->nextval('topics');
             $opts->{change_id} = $self->new_change;
 
@@ -89,15 +98,26 @@ sub run {
                 },
             );
 
-            my $path = $dbw->xval(
-                select => 'path',
-                from   => 'topic_path tp',
-                where  => { 'tp.id' => $opts->{id} },
+            $self->start_work(
+                topic_id      => $opts->{id},
+                start         => $start,
+                start_comment => "new issue",
+                billable      => 1,
+            );
+
+            $self->stop_work(
+                stop    => time,
+                restore => 1,
+            );
+
+            $self->save_work(
+                topic_id  => $opts->{id},
+                change_id => $opts->{change_id}
             );
 
             $self->end_change(
                 id                => $opts->{change_id},
-                action_format     => "new issue %s ($path)",
+                action_format     => "new issue %s",
                 action_topic_id_1 => $opts->{id},
                 message           => $opts->{message},
             );
@@ -119,7 +139,7 @@ bif-new-issue - add a new issue to a project
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
