@@ -5,7 +5,7 @@ use Bif::Mo;
 use IO::Prompt::Tiny qw/prompt/;
 use DBIx::ThinSQL qw/ qv sq/;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub dup {
@@ -23,11 +23,11 @@ sub dup {
     );
 
     my $src = $dbw->xval(
-        select    => 'p.path',
-        from      => 'projects p',
-        left_join => 'hubs h',
-        on        => 'h.id = p.hub_id',
-        where     => { 'p.id' => $dup_pinfo->{id} },
+        select     => 't.path',
+        from       => 'projects p',
+        inner_join => 'topics t',
+        on         => 't.id = p.id',
+        where      => { 'p.id' => $dup_pinfo->{id} },
     );
 
     $opts->{message} ||=
@@ -56,13 +56,13 @@ sub dup {
             );
 
             # TODO: unecessary?
-            if ( $dup_pinfo->{hub_id} ) {
+            if ( $dup_pinfo->{default_hub_id} ) {
                 $dbw->xdo(
                     insert_into => 'func_update_project',
                     values      => {
                         id        => $opts->{id},
                         change_id => $opts->{change_id},
-                        hub_id    => $dup_pinfo->{hub_id},
+                        hub_id    => $dup_pinfo->{default_hub_id},
                     },
                 );
             }
@@ -148,16 +148,10 @@ sub dup {
                 );
             }
 
-            my $path = $dbw->xval(
-                select => 'path',
-                from   => 'topic_path tp',
-                where  => { 'tp.id' => $opts->{id} },
-            );
-
             $self->end_change(
                 id => $opts->{change_id},
                 action_format =>
-                  "new project $path (%s) --dup $dup_pinfo->{path} (%s)]",
+"new project $opts->{path} (%s) --dup $dup_pinfo->{path} (%s)]",
                 action_topic_id_1 => $opts->{id},
                 action_topic_id_1 => $dup_pinfo->{id},
                 message           => $opts->{message},
@@ -295,77 +289,91 @@ sub run {
     my $opts = $self->opts;
     my $dbw  = $self->dbw;
 
-    $opts->{path} ||= prompt( 'Path:', '' )
-      || return $self->err( 'ProjectPathRequired', 'project path is required' );
-
-    my @parts = split( '/', $opts->{path} );
-    $opts->{name} = pop @parts;
-
-    my $parent = join( '/', @parts );
-    my @parents = $dbw->get_projects($parent);
-
-    if ( @parents > 1 ) {
-        return $self->err( 'ParentProjectAmbiguous',
-            "parent path is ambiguous:\n    "
-              . join( "\n    ", map { $_->{path} } @parents ) );
-    }
-    elsif (@parents) {
-        $opts->{parent_id} = $parents[0]->{id};
-        @parts = split( '/', $parents[0]->{path} );
-    }
-    elsif (@parts) {
-        return $self->err( 'HubNotFound',
-            "hub or parent project not found: " . join( '/', @parts ) );
-    }
-    else {
-        unshift( @parts, 'local' );
-    }
-
-    $opts->{path} = join( '/', @parts, $opts->{name} );
-    my @x = $dbw->get_projects( $opts->{path} );
-    return $self->err( 'ProjectExists', "project exists: $opts->{path}" )
-      if @x;
-
-    my $where;
-    if ( $opts->{status} ) {
-        return $self->err( 'InvalidStatus',
-            'unknown status: ' . $opts->{status} )
-          unless $dbw->xarrayref(
-            select => 'count(*)',
-            from   => 'default_status',
-            where  => {
-                kind   => 'project',
-                status => $opts->{status},
-            }
-          );
-    }
-
-    return dup($self) if $opts->{dup};
-
-    $opts->{title} ||= prompt( 'Title:', '' )
-      || return $self->err( 'ProjectTitleequired',
-        'project title is required' );
-
-    $opts->{message} ||= $self->prompt_edit( opts => $self );
-    $opts->{lang} ||= 'en';
-
     $dbw->txn(
         sub {
-            $opts->{id} ||= $dbw->nextval('topics');
+            my $start = time;
+            $self->stop_work(
+                stop => $start,
+                save => 1,
+            );
+
+            $opts->{path} ||= prompt( 'Path:', '' )
+              || return $self->err( 'ProjectPathRequired',
+                'project path is required' );
+
+            my @parts = split( '/', $opts->{path} );
+            $opts->{name} = pop @parts;
+
+            my $parent = join( '/', @parts );
+            my @parents = $dbw->get_projects($parent);
+
+            if ( @parents > 1 ) {
+                return $self->err( 'ParentProjectAmbiguous',
+                    "parent path is ambiguous:\n    "
+                      . join( "\n    ", map { $_->{path} } @parents ) );
+            }
+            elsif (@parents) {
+                $opts->{parent_id} = $parents[0]->{id};
+                @parts = split( '/', $parents[0]->{path} );
+            }
+            elsif (@parts) {
+                return $self->err( 'HubNotFound',
+                    "hub or parent project not found: " . join( '/', @parts ) );
+            }
+
+            my @x = $dbw->get_projects( $opts->{path} );
+            return $self->err( 'ProjectExists',
+                "project exists: $opts->{path}" )
+              if @x;
+
+            my $where;
+            if ( $opts->{status} ) {
+                return $self->err( 'InvalidStatus',
+                    'unknown status: ' . $opts->{status} )
+                  unless $dbw->xarrayref(
+                    select => 'count(*)',
+                    from   => 'default_status',
+                    where  => {
+                        kind   => 'project',
+                        status => $opts->{status},
+                    }
+                  );
+            }
+
+            return dup($self) if $opts->{dup};
+
+            $opts->{title} ||= prompt( 'Title:', '' )
+              || return $self->err( 'ProjectTitleequired',
+                'project title is required' );
+
+            $opts->{message} ||= $self->prompt_edit( opts => $self );
+            $opts->{lang}    ||= 'en';
+            $opts->{id}      ||= $dbw->nextval('topics');
             $opts->{change_id} ||= $self->new_change;
 
             $self->new_project;
 
-            my $path = $dbw->xval(
-                select => 'path',
-                from   => 'topic_path tp',
-                where  => { 'tp.id' => $opts->{id} },
+            $self->start_work(
+                topic_id      => $opts->{id},
+                start         => $start,
+                start_comment => "new project",
+                billable      => 1,
+            );
+
+            $self->stop_work(
+                stop    => time,
+                restore => 1,
+            );
+
+            $self->save_work(
+                topic_id  => $opts->{id},
+                change_id => $opts->{change_id}
             );
 
             $self->end_change(
                 id                => $opts->{change_id},
                 message           => $opts->{message},
-                action_format     => "new project $path (%s)",
+                action_format     => "new project $opts->{path} (%s)",
                 action_topic_id_1 => $opts->{id},
             );
 
@@ -386,7 +394,7 @@ bif-new-project - create a new project
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
