@@ -7,7 +7,7 @@ use Config::Tiny;
 use Log::Any '$log';
 use Path::Tiny qw/path tempdir/;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 has subref => ( is => 'ro', );
@@ -32,10 +32,7 @@ sub run {
     $self->repo($tempdir);
 
     # Fake App::bif into thinking the database already exists
-    open( my $fh, '>', $tempdir->child( $self->dbfile( $self->DBVERSION ) ) )
-      or die "open: $!";
-    close($fh);
-
+    $tempdir->child( $self->dbfile( $self->DBVERSION ) )->touch;
     my $dbw = $self->dbw;
 
     # On windows at least, an SQLite handle on the database prevents a
@@ -103,7 +100,7 @@ bif-new-repo -  create an empty repository
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
