@@ -9,7 +9,7 @@ use DBIx::ThinSQL qw/qv/;
 use Log::Any '$log';
 use Path::Tiny;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub run {
@@ -26,8 +26,8 @@ sub run {
         $opts->{location} = path($3)->realpath;
     }
     elsif ( -d $opts->{location} ) {
-        ( $opts->{name} = $opts->{location} ) =~ s{/?(.*?)\.bif/?$}{$1};
         $opts->{location} = path( $opts->{location} )->realpath;
+        $opts->{name}     = $opts->{location}->basename;
     }
     else {
         return $self->err( 'HubNotFound', 'hub not found: %s',
@@ -35,13 +35,10 @@ sub run {
     }
 
     $log->debug("pull hub: $opts->{location}");
-
-    my @locations = $dbw->get_hub_repos( $opts->{location} );
-
-    return $self->err(
-        'RepoExists', 'hub already pulled: %s (%s)',
-        $locations[0]->{location}, ( $locations[0]->{name} || '' )
-    ) if (@locations);
+    if ( my $hub = $self->dbw->get_hub( $self->uuid2id( $opts->{location} ) ) )
+    {
+        warn "warning: hub already exists: $hub->{name}\n";
+    }
 
     $|++;    # no buffering
     my $error;
@@ -54,7 +51,7 @@ sub run {
         debug         => $opts->{debug},
         debug_bifsync => $opts->{debug_bifsync},
         on_update     => sub {
-            $self->lprint("$opts->{location}: $_[0]");
+            $self->lprint("$opts->{name}: $_[0]");
         },
         on_error => sub {
             $error = shift;
@@ -69,7 +66,13 @@ sub run {
         eval {
             $dbw->txn(
                 sub {
-                    my ( $status, $ref ) = $client->pull_hub( $opts->{name} );
+                    my $start = time;
+                    $self->stop_work(
+                        stop => $start,
+                        save => 1,
+                    );
+
+                    my ( $status, $ref ) = $client->pull_hub;
 
                     print "\n";
 
@@ -81,48 +84,23 @@ sub run {
                         return $status;
                     }
 
-                    my @repos = $dbw->xhashrefs(
-                        select     => [ 'p.name', 'hr.id', 'hr.location' ],
-                        from       => 'hubs h',
-                        inner_join => 'projects p',
-                        on         => 'p.id = h.id',
-                        left_join  => 'hub_repos hr',
-                        on    => 'hr.hub_id = h.id',
-                        where => { 'h.id' => $ref->[0] },
-                        limit => 1,
+                    $self->start_work(
+                        topic_id      => $ref->[0],
+                        start         => $start,
+                        start_comment => "pull hub",
+                        billable      => 1,
                     );
 
-                    my $repo;
-                    foreach my $try (@repos) {
-                        $repo = $try if $try->{location} eq $opts->{location};
-                    }
-
-                    unless ($repo) {
-                        $repo = $repos[0];
-                        warn "no match for default repo";
-                    }
-
-                    $dbw->xdo(
-                        update => 'hubs',
-                        set    => { default_repo_id => $repo->{id} },
-                        where  => { id => $ref->[0] },
-                    );
-
-                    $opts->{change_id} = $self->new_change;
-
-                    $self->end_change(
-                        id => $opts->{change_id},
-                        action_format =>
-                          "pull hub $opts->{name}\@$opts->{location}",
-                        message =>
-                          "Registered hub $repo->{name} at $opts->{location}",
+                    $self->stop_work(
+                        stop    => time,
+                        restore => 1,
                     );
 
                     $dbw->xdo(
                         insert_or_replace_into =>
                           [ 'bifkv', qw/key change_id change_id2/ ],
                         select =>
-                          [ qv('last_sync'), $opts->{change_id}, 'MAX(c.id)', ],
+                          [ qv('last_sync'), 'MAX(c.id)', 'MAX(c.id)', ],
                         from => 'changes c',
                     );
 
@@ -136,12 +114,13 @@ sub run {
             print "\n";
         }
 
-        $client->disconnect;
-        return $cv->send( !$error );
+        return $cv->send;
     };
 
-    return $self->ok('PullHub') if $cv->recv;
-    return $self->err( 'Unknown', $error );
+    $cv->recv;
+    $client->disconnect;
+    return $self->err( 'Unknown', $error ) if $error;
+    return $self->ok('PullHub');
 
 }
 
@@ -156,7 +135,7 @@ bif-pull-hub -  import project lists from a remote repository
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
