@@ -8,7 +8,7 @@ use Coro;
 use DBIx::ThinSQL qw/qv/;
 use Log::Any '$log';
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub run {
@@ -44,22 +44,22 @@ sub run {
         eval {
             $dbw->txn(
                 sub {
+                    my $start = time;
+                    $self->stop_work(
+                        stop => $start,
+                        save => 1,
+                    );
+
                     $|++;
                     my $status = $client->bootstrap_identity;
 
                     unless ( $status eq 'IdentityImported' ) {
                         $dbw->rollback;
-                        $error = "unexpected status received: $status";
+                        $error =
+"unexpected IdentityImported status received: $status";
                         return;
                     }
 
-                    # Need to merge the identity received for the
-                    # end_change() method to succeed below
-                    $dbw->xdo(
-                        insert_into => 'func_merge_changes',
-                        values      => { merge => 1 },
-                    );
-
                     my ( $iid, $uuid, $name, $sn ) = $dbw->xlist(
                         select => [
                             'bifkv.identity_id',
@@ -76,35 +76,33 @@ sub run {
                         where      => { key => 'self' },
                     );
 
-                    $self->end_change(
-                        id            => $self->new_change,
-                        message       => $opts->{message},
-                        action_format => $opts->{self}
-                        ? "pull identity %s [$uuid $name ($sn)] --self"
-                        : "pull identity %s [$uuid $name ($sn)]",
-                        action_topic_id_1 => $iid,
+                    $self->start_work(
+                        topic_id      => $iid,
+                        start         => $start,
+                        start_comment => "pull identity",
+                        billable      => 1,
                     );
 
-     #                    $dbw->xdo(
-     #                        insert_or_replace_into =>
-     #                          [ 'bifkv', qw/key change_id change_id2/ ],
-     #                        select => [ qv('last_sync'), $uid, 'MAX(c.id)', ],
-     #                        from   => 'changes c',
-     #                    );
-
+                    $self->stop_work(
+                        stop    => time,
+                        restore => 1,
+                    );
+                    print "\n";
                 }
             );
         };
 
         if ($@) {
             $error = $@;
+            print "\n";
         }
 
-        $client->disconnect;
-        return $cv->send( !$error );
+        return $cv->send;
     };
 
-    return $self->err( 'Unknown', $error ) unless $cv->recv;
+    $cv->recv;
+    $client->disconnect;
+    return $self->err( 'Unknown', $error ) if $error;
     return $self->ok('PullIdentity');
 }
 
@@ -119,7 +117,7 @@ bif-pull-identity - import an identity from a repository
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
