@@ -5,7 +5,7 @@ use feature 'state';
 use Bif::Mo;
 use DBIx::ThinSQL qw/concat qv/;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub run {
@@ -81,11 +81,11 @@ sub run {
 
                 if (@unsatisfied) {
                     my $name = $dbw->xval(
-                        select     => ['p.name'],
-                        from       => 'projects p',
+                        select     => ['t.name'],
+                        from       => 'topics t',
                         inner_join => 'hubs h',
                         on         => 'h.id = p.hub_id',
-                        where      => { 'p.id' => $pinfo->{id} },
+                        where      => { 't.id' => $pinfo->{id} },
                     );
 
                     @unsatisfied = join ', ', @unsatisfied;
@@ -130,15 +130,15 @@ sub run {
                 );
 
                 my $src = $dbw->xval(
-                    select => 'tp.path',
-                    from   => 'topic_path tp',
-                    where  => { 'tp.id' => $info->{id}, },
+                    select => 't.path',
+                    from   => 'topics t',
+                    where  => { 't.id' => $info->{id}, },
                 );
 
                 my $dest = $dbw->xval(
-                    select => 'tp.path',
-                    from   => 'topic_path tp',
-                    where  => { 'tp.id' => $id, },
+                    select => 't.path',
+                    from   => 'topics t',
+                    where  => { 't.id' => $id, },
                 );
 
                 $self->end_change(
@@ -168,7 +168,7 @@ bif-push-issue - push an issue to another project
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
