@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif::show';
 
 sub run {
@@ -32,8 +32,8 @@ sub run {
             'c.author_contact',
             'c.message',
             'e.local',
-            'h.name AS hub_name',
-            'hr.location AS hub_location'
+            'ht.name AS hub_name',
+            'h.location AS hub_location'
         ],
         from       => 'entities e',
         inner_join => 'topics t',
@@ -42,10 +42,10 @@ sub run {
         on         => 'c.id = t.first_change_id',
         inner_join => 'entities ec',
         on         => 'ec.id = e.contact_id',
+        inner_join => 'topics ht',
+        on         => 'ht.id = e.hub_id',
         inner_join => 'hubs h',
         on         => 'h.id = e.hub_id',
-        inner_join => 'hub_repos hr',
-        on         => 'hr.id = h.default_repo_id',
         where      => { 'e.id' => $opts->{id} },
     );
 
@@ -105,7 +105,7 @@ bif-show-entity - display a entity's current status
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
