@@ -3,15 +3,14 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif::show';
 
 sub run {
-    my $self  = shift;
-    my $opts  = $self->opts;
-    my $db    = $self->db;
-    my $hub   = $self->get_hub( $opts->{id} ? $opts->{id} : $opts->{name} );
-    my @repos = $db->get_hub_repos( $hub->{id} );
+    my $self = shift;
+    my $opts = $self->opts;
+    my $db   = $self->db;
+    my $hub  = $self->get_hub( $opts->{id} ? $opts->{id} : $opts->{name} );
 
     my @data;
 
@@ -23,16 +22,7 @@ sub run {
         ),
     );
 
-    foreach my $repo (@repos) {
-        push(
-            @data,
-            $self->header(
-                '  Location',
-                $repo->{location},
-                $repo->{isdefault} ? 'default' : ()
-            )
-        );
-    }
+    push( @data, $self->header( '  Location', $hub->{location}, ) );
 
     my $info = $db->xhashref(
         select     => [qw/t.ctime t.ctimetz t.mtime t.mtimetz/],
@@ -62,7 +52,7 @@ bif-show-hub - display a hub's current status
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
