@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use DBIx::ThinSQL qw/bv sum case coalesce concat qv sq/;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif::show';
 
 sub run {
@@ -79,28 +79,28 @@ sub run {
         ),
         select => [
             'i.id AS id',
-            'p.path',
+            'pt.path',
             'ist.status',
             'c.mtime AS mtime',
             'c.mtimetz AS mtimetz',
             'c.mtimetzhm AS mtimetzhm',
             "$now - c.mtime AS mtime_age",
-            'p.hub_id',
+            'p.default_hub_id',
         ],
         from       => 'ids',
         inner_join => 'issues i',
         on         => 'i.id = ids.id',
         inner_join => 'projects p',
         on         => 'p.id = i.project_id',
-        left_join  => 'hubs h',
-        on         => 'h.id = p.hub_id',
+        inner_join => 'topics pt',
+        on         => 'pt.id = i.project_id',
         inner_join => 'issue_status ist',
         on         => 'ist.id = i.issue_status_id',
         inner_join => 'topics t',
         on         => 't.id = i.id',
         inner_join => 'changes c',
         on         => 'c.id = t.first_change_id',
-        order_by   => 'p.path',
+        order_by   => 'pt.path',
     );
 
     my %seen;
@@ -145,7 +145,7 @@ bif-show-issue - display an issue's current status
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
