@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif::show';
 
 sub run {
@@ -21,7 +21,7 @@ sub run {
         select => [
             'topics.id',
             'substr(topics.uuid,1,8) as uuid',
-            'projects.path',
+            'topics.path',
             'projects.title',
             'topics.ctime AS ctime',
             'topics.ctimetz AS ctimetz',
@@ -37,9 +37,9 @@ sub run {
             'project_status.status',
             'project_status.status',
             'projects.local',
-            'hp.name AS hub',
-            't2.uuid AS hub_uuid',
-            'hr.location',
+            'ht.name AS hub',
+            'ht.uuid AS hub_uuid',
+            'h.location',
         ],
         from       => 'projects',
         inner_join => 'topics',
@@ -48,14 +48,10 @@ sub run {
         on         => 'changes.id = topics.first_change_id',
         inner_join => 'project_status',
         on         => 'project_status.id = projects.project_status_id',
-        left_join  => 'projects hp',
-        on         => 'hp.id = projects.hub_id',
+        left_join  => 'topics ht',
+        on         => 'ht.id = projects.default_hub_id',
         left_join  => 'hubs h',
-        on         => 'h.id = projects.hub_id',
-        left_join  => 'hub_repos hr',
-        on         => 'hr.id = h.default_repo_id',
-        left_join  => 'topics t2',
-        on         => 't2.id = h.id',
+        on         => 'h.id = projects.default_hub_id',
         where      => { 'projects.id' => $info->{id} },
     );
 
@@ -177,7 +173,7 @@ bif-show-project - display a project's current status
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
