@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif::show';
 
 sub run {
@@ -22,9 +22,9 @@ sub run {
         select => [
             't.id AS id',
             't.uuid as uuid',
-            'tp.path AS path',
-            'hp.name AS hub',
-            'hr.location',
+            't.path AS path',
+            'ht.name AS hub',
+            'h.location',
             'substr(t2.uuid,1,8) AS project_uuid',
             'tasks.title AS title',
             't.ctime AS ctime',
@@ -58,18 +58,14 @@ sub run {
         on         => 'ts.id = tasks.task_status_id',
         inner_join => 'projects p',
         on         => 'p.id = ts.project_id',
-        left_join  => 'projects hp',
-        on         => 'hp.id = p.hub_id',
+        left_join  => 'topics ht',
+        on         => 'ht.id = p.default_hub_id',
         left_join  => 'hubs h',
-        on         => 'h.id = p.hub_id',
-        left_join  => 'hub_repos hr',
-        on         => 'hr.id = h.default_repo_id',
+        on         => 'h.id = p.default_hub_id',
         inner_join => 'topics t2',
         on         => 't2.id = p.id',
         inner_join => 'changes AS c12',
         on         => 'c12.id = tasks.change_id',
-        inner_join => 'topic_path tp',
-        on         => 'tp.id = t.id',
         where      => [ 't.id = ', qv( $info->{id} ) ],
     );
 
@@ -136,7 +132,7 @@ bif-show-task - display a task's current status
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
