@@ -7,7 +7,7 @@ use Bif::Mo;
 use Coro;
 use DBIx::ThinSQL qw/qv/;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub run {
@@ -15,26 +15,14 @@ sub run {
     my $opts = $self->opts;
     my $dbw  = $self->dbw;
 
-    if ( $opts->{hub} ) {
-        foreach my $name ( @{ $opts->{hub} } ) {
-            my @rl = $dbw->get_hub_repos($name);
-            $self->err( 'HubNotFound', 'hub not found: ' . $name )
-              unless @rl;
-        }
-    }
-
     # Consider upping PRAGMA cache_size? Or handle that in Bif::Role::Sync?
     my @hubs = $dbw->xhashrefs(
-        select     => [ 'h.id', 'p.name', 'hr.location', 't.uuid' ],
+        select     => [ 'h.id', 't.name', 'h.location', 't.uuid' ],
         from       => 'hubs h',
         inner_join => 'topics t',
         on         => 't.id = h.id',
-        inner_join => 'projects p',
-        on         => 'p.id = h.id',
-        inner_join => 'hub_repos hr',
-        on => 'hr.id = h.default_repo_id',
-        $opts->{hub} ? ( where => { 'p.name' => $opts->{hub} } ) : (),
-        order_by => 'p.name',
+        $opts->{hub} ? ( where => { 't.name' => $opts->{hub} } ) : (),
+        order_by => 't.name',
     );
 
     return $self->err( 'SyncNone', 'no (matching) hubs found' )
@@ -68,65 +56,73 @@ sub run {
             eval {
                 $dbw->txn(
                     sub {
-                        my $status = $client->sync_hub( $hub->{id} );
+                        $self->start_work(
+                            topic_id      => $hub->{id},
+                            start         => time,
+                            start_comment => "sync",
+                            billable      => 1,
+                            save          => 1,
+                        );
 
-                        unless ( $status eq 'RepoMatch'
-                            or $status eq 'RepoSync' )
+                        my @status = $client->sync_hub( $hub->{id} );
+
+                        unless ( $status[0] eq 'HubMatch'
+                            or $status[0] eq 'HubSync' )
                         {
                             $dbw->rollback;
-                            $error = "unexpected status received: $status";
+                            $error =
+"unexpected HubSync/Match status received: @status";
                             return;
 
                         }
 
-                        if ( $status eq 'RepoSync' ) {
-                            $status = $client->transfer_hub_changes;
-                            if ( $status ne 'TransferHubChanges' ) {
+                        if ( $status[0] eq 'HubSync' ) {
+                            @status = $client->transfer_hub_changes;
+                            if ( $status[0] ne 'TransferHubChanges' ) {
                                 $dbw->rollback;
-                                $error = "unexpected status received: $status";
+                                $error =
+"unexpected TransferHubChanges status received: @status";
                                 return;
                             }
                         }
 
-                        $status = $client->sync_projects;
+                        @status = $client->sync_projects;
 
-                        unless ( $status eq 'ProjectSync' ) {
+                        unless ( $status[0] eq 'ProjectSync'
+                            or $status[0] eq 'ProjectMatch' )
+                        {
                             $dbw->rollback;
-                            $error = "unexpected status received: $status";
+                            $error =
+"unexpected ProjectSync/Matc status received: @status";
                             return;
                         }
 
-                        $status = $client->transfer_project_related_changes;
+                        if ( $status[0] eq 'ProjectSync' ) {
+                            @status = $client->transfer_project_related_changes;
 
-                        if ( $status ne 'TransferProjectRelatedChanges' ) {
-                            $dbw->rollback;
-                            $error = "unexpected status received: $status";
-                            return;
+                            if ( $status[0] ne 'TransferProjectRelatedChanges' )
+                            {
+                                $dbw->rollback;
+                                $error =
+"unexpected TransferProjectRelatedChanges status received: @status";
+                                return;
+                            }
                         }
                         print "\n";
 
-                        $opts->{change_id} = $self->new_change;
-
-                        $self->end_change(
-                            id            => $opts->{change_id},
-                            action_format => "sync hub $hub->{name}\@"
-                              . "$hub->{location} (%s)",
-                            action_topic_id_1 => $hub->{id},
-                            message =>
-                              "sync hub $hub->{name} via $hub->{location}"
-                              . $opts->{message},
-                        );
-
                         $dbw->xdo(
                             insert_or_replace_into =>
                               [ 'bifkv', qw/key change_id change_id2/ ],
-                            select => [
-                                qv('last_sync'), $opts->{change_id},
-                                'MAX(c.id)',
-                            ],
+                            select =>
+                              [ qv('last_sync'), 'MAX(c.id)', 'MAX(c.id)', ],
                             from => 'changes c',
                         );
 
+                        $self->stop_work(
+                            stop    => time,
+                            restore => 1,
+                        );
+
                         return;
                     }
                 );
@@ -137,15 +133,13 @@ sub run {
                 print "\n";
             }
 
-            $client->disconnect;
-            return $cv->send( !$error );
+            return $cv->send;
         };
 
-        if ( $cv->recv ) {
-            next;
-        }
+        $cv->recv;
+        $client->disconnect;
 
-        return $self->err( 'Unknown', $error );
+        return $self->err( 'Unknown', $error ) if $error;
 
     }
 
@@ -168,7 +162,7 @@ bif-sync -  exchange changes with hubs
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
