@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub run {
@@ -15,19 +15,27 @@ sub run {
     return $self->err( 'IdentityNotFound', "identity not found: $opts->{id}" )
       unless $info;
 
-    if ( $opts->{reply} ) {
-        my $uinfo =
-          $self->get_change( $opts->{reply}, $info->{first_change_id} );
-        $opts->{parent_uid} = $uinfo->{id};
-    }
-    else {
-        $opts->{parent_uid} = $info->{first_change_id};
-    }
-
-    $opts->{message} ||= $self->prompt_edit( opts => $self );
-
     $dbw->txn(
         sub {
+            $self->start_work(
+                topic_id      => $info->{id},
+                start         => time,
+                start_comment => "update identity",
+                billable      => 1,
+                save          => 1,
+            );
+
+            if ( $opts->{reply} ) {
+                my $uinfo =
+                  $self->get_change( $opts->{reply}, $info->{first_change_id} );
+                $opts->{parent_uid} = $uinfo->{id};
+            }
+            else {
+                $opts->{parent_uid} = $info->{first_change_id};
+            }
+
+            $opts->{message} ||= $self->prompt_edit( opts => $self );
+
             $opts->{change_id} =
               $self->new_change( parent_id => $opts->{parent_uid}, );
 
@@ -41,16 +49,20 @@ sub run {
                 },
             );
 
-            my $path = $dbw->xval(
-                select => 'path',
-                from   => 'topic_path tp',
-                where  => { 'tp.id' => $opts->{id} },
+            $self->stop_work(
+                stop    => time,
+                restore => 1,
+            );
+
+            $self->save_work(
+                topic_id  => $info->{id},
+                change_id => $opts->{change_id}
             );
 
             $self->end_change(
                 id                => $opts->{change_id},
                 message           => $opts->{message},
-                action_format     => "update identity %s ($path)",
+                action_format     => "update identity %s",
                 action_topic_id_1 => $info->{id},
             );
 
@@ -71,7 +83,7 @@ bif-update-identity - update or comment an identity
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
