@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub run {
@@ -34,10 +34,18 @@ sub run {
         $opts->{parent_uid} = $info->{first_change_id};
     }
 
-    $opts->{message} ||= $self->prompt_edit( opts => $self );
-
     $dbw->txn(
         sub {
+            $self->start_work(
+                topic_id      => $info->{id},
+                start         => time,
+                start_comment => "update issue",
+                billable      => 1,
+                save          => 1,
+            );
+
+            $opts->{message} ||= $self->prompt_edit( opts => $self );
+
             $opts->{change_id} =
               $self->new_change( parent_id => $opts->{parent_uid}, );
 
@@ -51,15 +59,19 @@ sub run {
                 },
             );
 
-            my $path = $dbw->xval(
-                select => 'path',
-                from   => 'topic_path tp',
-                where  => { 'tp.id' => $opts->{id} },
+            $self->stop_work(
+                stop    => time,
+                restore => 1,
+            );
+
+            $self->save_work(
+                topic_id  => $info->{id},
+                change_id => $opts->{change_id}
             );
 
             $self->end_change(
                 id                => $opts->{change_id},
-                action_format     => "update issue %s ($path)",
+                action_format     => "update issue %s",
                 action_topic_id_1 => $info->{id},
                 message           => $opts->{message},
             );
@@ -81,7 +93,7 @@ bif-update-issue - update an issue
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
