@@ -4,9 +4,8 @@ use warnings;
 use Bif::Mo;
 use DBIx::ThinSQL qw/sq qv/;
 use IO::Prompt::Tiny qw/prompt/;
-use Time::Duration qw/concise duration/;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub run {
@@ -20,7 +19,7 @@ sub run {
               $self->get_project( $opts->{id} ? $opts->{id} : $opts->{path} );
 
             $self->start_work(
-                id            => $info->{id},
+                topic_id      => $info->{id},
                 start         => time,
                 start_comment => "update project",
                 billable      => 1,
@@ -53,61 +52,29 @@ sub run {
             $opts->{change_id} =
               $self->new_change( parent_id => $opts->{parent_uid}, );
 
+            $dbw->xdo(
+                insert_into => 'func_update_project',
+                values      => {
+                    id                => $info->{id},
+                    change_id         => $opts->{change_id},
+                    title             => $opts->{title},
+                    project_status_id => $status_ids->[0],
+                }
+            );
+
             $self->stop_work(
-                id      => $opts->{id},
                 stop    => time,
                 restore => 1,
             );
 
-            $dbw->xdo(
-                with => 'w',
-                as   => sq(
-                    select => 'sum(wb.stop - wb.start) AS delta',
-                    from   => 'work_buffers wb',
-                    where  => {
-                        'wb.topic_id'  => $info->{id},
-                        'wb.billable'  => 1,
-                        'wb.change_id' => undef,
-                    },
-                    group_by => 'null',
-                    having   => 'delta > 0',
-                ),
-                insert_into => [
-                    'func_update_project', qw/id change_id
-                      work_delta title project_status_id/
-                ],
-                select => [
-                    qv( $info->{id} ),
-                    qv( $opts->{change_id} ),
-                    'w.delta',
-                    qv( $opts->{title} ),
-                    qv( $status_ids->[0] ),
-                ],
-
-                from      => '(select 1)',
-                left_join => 'w',
-            );
-
-            $dbw->xdo(
-                update => 'work_buffers',
-                set    => { change_id => $opts->{change_id} },
-                where  => {
-                    topic_id  => $info->{id},
-                    billable  => 1,
-                    change_id => undef,
-                    'stop !'  => undef,
-                },
-            );
-
-            my $path = $dbw->xval(
-                select => 'path',
-                from   => 'topic_path tp',
-                where  => { 'tp.id' => $opts->{id} },
+            $self->save_work(
+                topic_id  => $info->{id},
+                change_id => $opts->{change_id},
             );
 
             $self->end_change(
                 id                => $opts->{change_id},
-                action_format     => "update project $path (%s)",
+                action_format     => "update project $info->{path} (%s)",
                 action_topic_id_1 => $info->{id},
                 message           => $opts->{message},
             );
@@ -129,7 +96,7 @@ bif-update-project - update a project
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
