@@ -7,11 +7,12 @@ use DBIx::ThinSQL qw/sq/;
 use Log::Any '$log';
 use Path::Tiny;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub run {
     my $self = shift;
+    my $opts = $self->opts;
     my $repo = $self->repo;
 
     # Loop backwards from the software version until we find the
@@ -26,8 +27,8 @@ sub run {
     my $current = pop @steps;
     my ( $latest_major, $latest_minor ) = $self->minor_upgrade($current);
 
-    if ( $self->opts->{force} and !@steps ) {
-        print "Forcing upgrade\n";
+    if ( $opts->{force} and !@steps ) {
+        $self->lprint("Forcing upgrade");
         push( @steps, $self->DBVERSION );
     }
 
@@ -43,23 +44,24 @@ sub run {
         # This should be the first use of self->dbw and so should appear in
         # the updated DB
 
-        $self->dbw->txn(
-            sub {
-                $self->end_change(
-                    id            => $self->new_change,
-                    action_format => 'upgrade',
-                    message =>
-                      "Upgraded repository to v$latest_major.$latest_minor",
-                );
-
-            }
-        );
+   # TODO: Make this a work-buffer item
+   #        $self->dbw->txn(
+   #            sub {
+   #                $self->end_change(
+   #                    id            => $self->new_change,
+   #                    action_format => 'upgrade',
+   #                    message =>
+   #                      "Upgraded repository to v$latest_major.$latest_minor",
+   #                );
+   #
+   #            }
+   #        );
     }
 
-    printf("Analyzing");
+    $self->lprint("Analyzing");
     $self->dbw->do('ANALYZE');
-    printf("Checking UUIDs");
     $self->dispatch('App::bif::check');
+    return $self->ok('ForceUpgrade') if $opts->{force};
     return $self->ok('Upgrade');
 }
 
@@ -74,11 +76,11 @@ sub minor_upgrade {
         sub {
             my ( $old, $new ) = $db->deploy($major);
             if ( $new > $old ) {
-                printf( "Database upgraded (v%d.%d-v%d.%d)\n",
+                printf( "Original database upgraded (v%d.%d-v%d.%d)\n",
                     $major, $old, $major, $new );
             }
             else {
-                printf( "Database remains at v%d.%d\n", $major, $new );
+                printf( "Original database v%d.%d\n", $major, $new );
             }
             return ( $major, $new );
         }
@@ -118,27 +120,33 @@ sub generic_upgrade {
     my $minor;
     $next_db->txn(
         sub {
-            print "Deploying db-v$next\n";
+            $self->lprint("Deploying new database v$next");
             ( undef, $minor ) = $next_db->deploy($next);
-            my $current_prepare = 'xprepare_changeset_v' . $current;
-            my $current_sth     = $current_db->$current_prepare(
-                with => 'src',
-                as   => sq(
-                    select   => 'c.id AS id',
-                    from     => 'changes c',
-                    order_by => 'c.id ASC',
-                ),
+            $self->lprint("New database v$next.$minor\n");
+
+            my $total = $current_db->xval(
+                select => 'count(*)',
+                from   => 'changes',
             );
-            $current_sth->execute;
 
-            my $current_changeset = 'changeset_v' . $current;
-            my $next_changeset    = 'insert_changeset_v' . $next;
+            my $src = $current_db->xprepare(
+                select   => 'c.id AS id',
+                from     => 'changes c',
+                order_by => 'c.id ASC',
+            );
+            $src->execute;
 
-            print "Migrating data\n";
-            while ( my $changeset = $current_sth->$current_changeset ) {
-                $next_db->$next_changeset($changeset);
+            my $i = 0;
+            while ( defined( my $id = $src->val ) ) {
+                $self->lprint( 'Importing change ' . $i . '/' . $total );
+                my $changeset = $current_db->changeset_v1($id);
+                $next_db->save_changeset_v1( $id, $changeset );
+                $i++;
             }
 
+            $self->lprint( 'Imported changes: ' . $total . "\n" );
+            $self->lprint("Running fixups\n");
+
             my @bif = $current_db->xhashrefs(
                 select   => '*',
                 from     => 'bifkv',
@@ -166,29 +174,49 @@ sub generic_upgrade {
                 );
             }
 
-            my @hub_defs = $current_db->xhashrefs(
-                select => [qw/id default_repo_id/],
-                from   => 'hubs',
+            my @project_defs = $current_db->xhashrefs(
+                select => [qw/id default_hub_id local/],
+                from   => 'projects',
             );
 
-            foreach my $hub (@hub_defs) {
+            foreach my $project (@project_defs) {
                 $next_db->xdo(
-                    update => 'hubs',
-                    set    => { default_repo_id => $hub->{default_repo_id} },
-                    where  => { id => $hub->{id} },
+                    update => 'projects',
+                    set    => {
+                        default_hub_id => $project->{default_hub_id},
+                        local          => $project->{local}
+                    },
+                    where => { id => $project->{id} },
                 );
             }
+
+            my $next_count = $next_db->xval(
+                select => 'count(id)',
+                from   => 'changes',
+            );
+
+            return $self->err( 'CountMismatch',
+                "next count (%d) != current count (%d)",
+                $next_count, $current_count )
+              unless $next_count == $current_count;
+
+            $next_db->xdo(
+                insert_into => 'func_merge_changes',
+                values      => { merge => 1 },
+            );
+
+            $self->lprint("Running PRAGMA foreign_key_check\n");
+            my $sth = $next_db->prepare('PRAGMA foreign_key_check');
+            $sth->execute;
+            if ( my @bad = $sth->arrayrefs ) {
+                print $self->render_table( ' l  r  l  r ',
+                    [qw/Parent ID Destination Key/], \@bad );
+                return $self->err( 'ForeignKeyCheck',
+                    'unsatisfied foreign keys' );
+            }
         }
     );
 
-    my $next_count = $next_db->xval(
-        select => 'count(id)',
-        from   => 'changes',
-    );
-
-    die "next count ($next_count) != current count ($current_count)"
-      unless $next_count == $current_count;
-
     $next_db->disconnect;
 
     rename $next_file, $self->repo->child( $self->dbfile($next) );
@@ -206,7 +234,7 @@ bif-upgrade - upgrade a repository
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
