@@ -3,10 +3,9 @@ use strict;
 use warnings;
 use Bif::Mo;
 use DBIx::ThinSQL qw/concat coalesce qv/;
-use Time::Duration qw/concise duration/;
 use IO::Prompt::Tiny qw/prompt/;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 extends 'App::bif';
 
 sub run {
@@ -18,8 +17,7 @@ sub run {
     # Nothing specified, just display the status
     if ( !exists $opts->{id} ) {
         if ($work) {
-            printf "working %s %s [%s] %s (since %s)\n", $work->{kind},
-              $work->{id},
+            printf "working %s %s %s (since %s)\n", $work->{kind},
               $work->{path},
               $self->s2hm( time - $work->{start} ),
               scalar localtime( $work->{start} );
@@ -37,12 +35,10 @@ sub run {
         # But only if we were actually working
         if ($work) {
             $self->stop_work(
-                topic_id     => $opts->{id},
                 stop         => $epoch,
                 stop_comment => $opts->{comment},
             );
-            printf "stopped working %s %s [%s] after %s\n", $work->{kind},
-              $work->{id},
+            printf "stopped working %s %s after %s\n", $work->{kind},
               $work->{path},
               $self->s2hm( $epoch - $work->{start} );
             return $self->ok('StopWork');
@@ -65,8 +61,7 @@ sub run {
 
         $opts->{comment} ||= prompt( 'Comment:', '' );
         $self->stop_work( stop => $epoch - 1 );
-        printf "stopped working %s %s [%s] after %s\n", $work->{kind},
-          $work->{id},
+        printf "stopped working %s %s after %s\n", $work->{kind},
           $work->{path},
           $self->s2hm( $epoch - $work->{start} );
     }
@@ -76,7 +71,7 @@ sub run {
 
     # Finally, start the new work
     $self->start_work(
-        id            => $info->{id},
+        topic_id      => $info->{id},
         start         => $epoch,
         start_comment => $opts->{comment},
         billable      => $opts->{not_billable} ? 0 : 1,
@@ -84,8 +79,7 @@ sub run {
 
     $work = $self->current_work;
 
-    printf "working %s %s [%s] since %s\n", $work->{kind},
-      $work->{id},
+    printf "working %s %s since %s\n", $work->{kind},
       $work->{path},
       scalar localtime( $work->{start} );
 
@@ -103,7 +97,7 @@ bif-work - track your work on a topic
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
