@@ -6,7 +6,7 @@ use DBIx::ThinSQL ();
 use Carp          ();
 use Log::Any '$log';
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 our @ISA     = ('DBIx::ThinSQL');
 
 sub _connected {
@@ -119,17 +119,17 @@ sub get_projects {
                 't.kind AS kind',
                 't.uuid AS uuid',
                 'p.parent_id AS parent_id',
-                'p.path AS path',
+                't.path AS path',
                 't.first_change_id AS first_change_id',
-                'p.hub_id AS hub_id',
+                'p.default_hub_id AS default_hub_id',
                 'p.local AS local',
                 'h.name AS hub_name',
             ],
             from       => 'projects p',
             inner_join => 'topics t',
             on         => 't.id = p.id',
-            left_join  => 'projects h',
-            on         => 'h.id = p.hub_id',
+            left_join  => 'topics h',
+            on         => 'h.id = p.default_hub_id',
             where      => { 'p.id' => $path },
         );
     }
@@ -139,20 +139,20 @@ sub get_projects {
             't.id AS id',
             't.kind AS kind',
             't.uuid AS uuid',
-            'p.parent_id AS parent_id',
-            'p.path AS path',
+            't.parent_id AS parent_id',
+            't.path AS path',
             't.first_change_id AS first_change_id',
-            'p.hub_id AS hub_id',
+            'p.default_hub_id AS default_hub_id',
             'p.local AS local',
             'h.name AS hub_name',
         ],
-        from       => 'projects p',
-        inner_join => 'topics t',
-        on         => 't.id = p.id',
-        left_join  => 'projects h',
-        on         => 'h.id = p.hub_id',
-        where      => [ 'p.path = ', qv($path), ' OR p.name = ', qv($path) ],
-        order_by   => [qw/p.path/],
+        from       => 'topics t',
+        inner_join => 'projects p',
+        on         => 'p.id = t.id',
+        left_join  => 'topics h',
+        on         => 'h.id = p.default_hub_id',
+        where      => [ 't.path = ', qv($path), ' OR t.name = ', qv($path) ],
+        order_by   => [qw/t.path/],
     );
 }
 
@@ -181,64 +181,26 @@ sub status_ids {
     return \@ids, [ sort keys %invalid ];
 }
 
-sub get_hub_repos {
+sub get_hub {
     my $self = shift;
     my $hub = shift || return;
 
-    return $self->xhashrefs(
-
-        # TODO get rid of this select once everything uses ctx->uuid2id
+    return $self->xhashref(
         select => [
-            'p.id AS id',
-            't.uuid AS uuid',
-            'p.name AS name',
-            'hr.location AS location',
-            'h.default_repo_id = hr.id AS is_default'
+            qw/h.id t.name t.kind t.uuid h.location t.first_change_id/,
+            , 'b.hub_id AS is_default'
         ],
-        from       => 'projects p',
+        from       => 'topics t',
         inner_join => 'hubs h',
-        on         => 'h.id = p.id',
-        inner_join => 'topics t',
-        on         => 't.id = h.id',
-        inner_join => 'hub_repos hr',
-        on         => 'hr.hub_id = h.id',
-        where      => {
-            'p.name' => $hub,
-        },
-        union_all_select => [
-            'h.id AS id',
-            't.uuid AS uuid',
-            'p.name AS name',
-            'hr.location AS location',
-            'h.default_repo_id = hr.id AS is_default'
-        ],
-        from       => 'projects p',
-        inner_join => 'hubs h',
-        on         => 'p.id = h.id',
-        inner_join => 'topics t',
-        on         => 't.id = h.id',
-        inner_join => 'hub_repos hr',
-        on         => 'hr.hub_id = h.id',
-        where      => {
-            'h.id' => $hub,
-        },
-        union_all_select => [
-            'h.id', 't.uuid', 'p.name',
-            'hr.location', 'h.default_repo_id = hr.id AS is_default'
-        ],
-        from       => 'hub_repos hr2',
-        inner_join => 'hubs h',
-        on         => 'h.id = hr2.hub_id',
+        on         => 'h.id = t.id',
         inner_join => 'projects p',
         on         => 'p.id = h.id',
-        inner_join => 'topics t',
-        on         => 't.id = h.id',
-        inner_join => 'hub_repos hr',
-        on         => 'hr.hub_id = h.id',
-        where      => {
-            'hr2.location' => $hub,
-        },
-        order_by => [qw/name location/],
+        left_join  => 'bifkv b',
+        on         => 'b.key = "local" AND b.hub_id = h.id',
+        where      => [
+            't.name = ',   qv($hub), ' OR h.location = ', qv($hub),
+            ' OR h.id = ', qv($hub)
+        ],
     );
 }
 
@@ -302,7 +264,7 @@ Bif::DB - helper methods for a read-only bif database
 
 =head1 VERSION
 
-0.1.5_3 (2015-06-30)
+0.1.5_4 (2015-08-04)
 
 =head1 SYNOPSIS
 
@@ -372,7 +334,7 @@ and returns a list of hash references containg the following keys:
 
 =item * parent_id - the parent ID of the project
 
-=item * hub_id - the id of the project's hub
+=item * default_hub_id - the id of the project's default hub
 
 =item * hub_name - the name of the project's hub
 
@@ -392,10 +354,10 @@ status names and returns an arrayref of matching IDs, and an arrayref
 of invalid names. This method will silently ignore any @status which
 are undefined.
 
-=item get_hub_repos( $name ) -> @HashRef
+=item get_hub( $name ) -> @HashRef
 
-Returns a list of HASH references containing information about the hub
-identified by C<$name>, each with the following keys:
+Returns a HASH reference containing information about the hub
+identified by C<$name> with the following keys:
 
 =over
 
