@@ -4,10 +4,11 @@ use warnings;
 use Bif::DB::Plugin::ChangeUUIDv1;
 use Bif::Mo;
 use Coro;
+use DBIx::ThinSQL qw/qv/;
 use Log::Any '$log';
 use JSON;
 
-our $VERSION = '0.1.5_3';
+our $VERSION = '0.1.5_4';
 
 has changes_dup => (
     is      => 'rw',
@@ -73,7 +74,7 @@ sub new_temp_table {
 
     $self->db->do( 'CREATE TEMPORARY TABLE '
           . $tmp . '('
-          . 'id INTEGER UNIQUE ON CONFLICT IGNORE,'
+          . 'id INTEGER NOT NULL UNIQUE ON CONFLICT IGNORE,'
           . 'ucount INTEGER'
           . ')' );
 
@@ -84,7 +85,7 @@ sub new_temp_table {
 sub read {
     my $self = shift;
 
-    my $json = $self->rh->readline("\015");
+    my $json = $self->rh->readline("\n");
 
     if ( !defined $json ) {
         $self->on_error->('connection close/timeout');
@@ -115,12 +116,138 @@ sub write {
 
     $log->debugf( 'w: %s', \@_ );
 
-    return $self->wh->print( $self->json->encode( \@_ ) . "\015" );
+    return $self->wh->print( $self->json->encode( \@_ ) . "\n" );
 }
 
 # Let sub classes override if necessary
 sub trigger_on_update { }
 
+sub real_sync {
+    my $self      = shift;
+    my $kind      = shift || die 'real_sync($KIND,$id,$prefix,$change_id)';
+    my $id        = shift;
+    my $prefix    = shift // '';
+    my $change_id = shift;
+
+    if ( not defined $id ) {
+        $self->write( 'ProtocolError', 'real_sync($id)' );
+        return 'ProtocolError';
+    }
+
+    my $db        = $self->db;
+    my $tmp       = $self->temp_table;
+    my $hub_id    = $self->hub_id;
+    my $on_update = $self->on_update;
+    my $prefix2   = $prefix . '_';
+
+    $on_update->( 'matching: ' . $prefix2 ) if $on_update;
+
+    my @refs;
+
+    # Case 2b (see below): this end is a leaf node so fake the prefix stuff
+    if ($change_id) {
+        @refs = $db->xhashrefs(
+            select => [
+                'SUBSTR(c.uuid, 1, LENGTH(Xc.prefix)+1) AS prefix',
+                'Xc.hash AS hash',
+                'Xc.change_id AS change_id'
+            ],
+            from       => "${kind}_changes Xc",
+            inner_join => 'changes c',
+            on         => 'c.id = Xc.change_id',
+            where      => {
+                "Xc.${kind}_id" => $id,
+                'Xc.change_id'  => $change_id,
+                'Xc.prefix'     => $prefix,
+            },
+        );
+    }
+
+    # Branch node comparison
+    else {
+        @refs = $db->xhashrefs(
+            select => [
+                'Xc.prefix AS prefix',
+                'Xc.hash AS hash',
+                'Xc.change_id AS change_id'
+            ],
+            from  => "${kind}_changes Xc",
+            where => {
+                "Xc.${kind}_id"  => $id,
+                'Xc.prefix LIKE' => $prefix2,
+            },
+            order_by => 'Xc.prefix',
+        );
+    }
+
+    $self->write(
+        'MATCH', $prefix2,
+        {
+            map { $_->{prefix} => [ $_->{hash}, $_->{change_id} ? 1 : 0 ] }
+              @refs
+        }
+    );
+
+    my ( $action, $mprefix, $there ) = $self->read;
+
+    return "expected MATCH $prefix2 {} (not $action $mprefix ...)"
+      unless $action eq 'MATCH'
+      and $mprefix eq $prefix2
+      and ref $there eq 'HASH';
+
+    my @next;
+    my @prefix;
+
+    foreach my $ref (@refs) {
+
+        # Case 1: Prefix does not exist at other end
+        if ( !exists $there->{ $ref->{prefix} } ) {
+            push( @prefix, ' OR ' ) if @prefix;
+            push( @prefix,
+                "Xc.prefix LIKE ",
+                qv( $ref->{prefix} . '%' ),
+                ' AND Xc.change_id IS NOT NULL' );
+        }
+
+        # Case 2: Prefix hash is not the same
+        elsif ( $there->{ $ref->{prefix} }->[0] ne $ref->{hash} ) {
+
+            # Case 2a: both ends are leaf nodes
+            if ( $there->{ $ref->{prefix} }->[1] and $ref->{change_id} ) {
+                push( @prefix, ' OR ' ) if @prefix;
+                push( @prefix, "Xc.change_id = ", qv( $ref->{change_id} ) );
+            }
+
+            # Case 2b: this end is a leaf node
+            elsif ( $ref->{change_id} ) {
+                push( @next, [ $ref->{prefix}, $ref->{change_id} ] );
+            }
+
+            # Case 2c: this end, and *maybe* other end are branch nodes
+            else {
+                push( @next, [ $ref->{prefix} ] );
+            }
+        }
+    }
+
+    if (@prefix) {
+        $self->db->xdo(
+            insert_into => "$tmp(id)",
+            select      => 'Xc.change_id',
+            from        => "${kind}_changes Xc",
+            where => [ "Xc.${kind}_id = ", qv($id), ' AND (', @prefix, ')' ],
+        );
+    }
+
+    if (@next) {
+        foreach my $next ( sort { $a->[0] cmp $b->[0] } @next ) {
+            $self->real_sync( $kind, $id, @$next );
+        }
+    }
+
+    return ucfirst($kind) . 'Sync' . $prefix;
+}
+
 sub real_send_changesets {
     my $self       = shift;
     my $total      = shift;
@@ -152,18 +279,17 @@ sub send_changesets {
     my $statements = shift;
 
     $self->write( 'TOTAL', $total );
-    my $r = $self->real_send_changesets( $total, $statements );
-    return $r unless $r eq 'SendChangesets';
+    my @r = $self->real_send_changesets( $total, $statements );
+    return @r unless $r[0] eq 'SendChangesets';
 
-    my ( $recv, $count ) = $self->read;
-    return 'SendChangesets' if $recv eq 'Recv' and $count == $total;
-    return $recv;
+    @r = $self->read;
+    return 'SendChangesets' if $r[0] eq 'Recv' and $r[1] == $total;
+    return @r;
 }
 
 sub recv_changesets {
-    my $self                = shift;
-    my $changeset_functions = shift;
-    my $db                  = $self->db;
+    my $self = shift;
+    my $db   = $self->db;
 
     my ( $action, $total ) = $self->read;
     $total //= '*undef*';
@@ -191,58 +317,14 @@ sub recv_changesets {
         return "expected CHANGSET not: $action"
           unless $action eq 'CHANGESET';
 
-        $self->changes_dup( $self->changes_dup + 1 )
-          unless $db->save_uchangeset_v1($changeset);
-
-=cut
-
-        if ( !exists $import_functions{$action} ) {
-            return "not implemented: $action";
+        my ( $res, $uuid ) = $db->save_uchangeset_v1($changeset);
+        if ( 0 == $res ) {
+            $self->changes_dup( $self->changes_dup + 1 );
         }
-
-        return "expected CHANGSET not: $action"
-          unless $action eq 'CHANGESET';
-
-        my $i = 0;
-        my $uuid;
-
-        foreach my $delta (@$changeset) {
-            my $type = delete $delta->{_}
-              || return "missing delta type";
-
-            my $func = $changeset_functions->{$type}
-              || return "unknown delta type: $type";
-
-            if ( 0 == $i ) {
-                $uuid = $delta->{uuid} || return 'missing [0]->{uuid}';
-
-                # For entities in particular we may already have this
-                # changeset so ignore it.
-                my $id = $db->xval(
-                    select => 'c.id',
-                    from   => 'changes c',
-                    where  => { 'c.uuid' => $uuid },
-                );
-
-                if ($id) {
-                    $self->changes_dup( $self->changes_dup + 1 );
-                    last;
-                }
-            }
-            else {
-                $delta->{change_uuid} = $uuid;
-            }
-
-            # This should be a savepoint?
-            $db->xdo(
-                insert_into => $func,
-                values      => $delta,
-            );
-
-            $i++;
-
+        elsif ( $res < 0 ) {
+            $self->write( 'UUIDMismatch', $uuid );
+            return ( 'UUIDMismatch', $uuid );
         }
-=cut
 
         $got++;
         $self->changes_recv( $self->changes_recv + 1 );
@@ -250,16 +332,20 @@ sub recv_changesets {
 
     }
 
+    $db->xdo(
+        insert_into => 'func_merge_changes',
+        values      => { merge => 1 },
+    );
+
     $self->write( 'Recv', $got );
     return 'RecvChangesets';
 }
 
 sub exchange_changesets {
-    my $self                = shift;
-    my $send_total          = shift;
-    my $send_statements     = shift;
-    my $changeset_functions = shift;
-    my $db                  = $self->db;
+    my $self            = shift;
+    my $send_total      = shift;
+    my $send_statements = shift;
+    my $db              = $self->db;
 
     # Ensure that this goes out before we get properly asynchronous,
     # particularly before recv_changesets() sends out a Recv message.
@@ -270,7 +356,7 @@ sub exchange_changesets {
     my $coro = async {
         select $fh;
 
-        $self->recv_changesets($changeset_functions);
+        $self->recv_changesets();
     };
 
     # Now send receiving changesets
