@@ -1,7 +1,7 @@
 CREATE TABLE func_new_hub(
     change_id INTEGER NOT NULL,
     id INTEGER NOT NULL,
-    set_default INTEGER DEFAULT 0,
+    location VARCHAR NOT NULL,
     uuid VARCHAR(40)
 );
 
@@ -15,7 +15,8 @@ BEGIN
     SELECT debug(
         NEW.change_id,
         NEW.id,
-        NEW.set_default
+        NEW.location,
+        NEW.uuid
     );
 
     UPDATE
@@ -24,18 +25,17 @@ BEGIN
         yaml = yaml
             || '-' || x'0A'
             || '  _delta: new_hub' || x'0A'
+            || CASE WHEN
+                instr(NEW.location, ' ')
+            THEN
+                '  location: ''' || NEW.location || '''' || x'0A'
+            ELSE
+                '  location: ' || NEW.location || x'0A'
+            END
     WHERE
         id = NEW.change_id
     ;
 
-
-    INSERT INTO hubs(
-        id
-    )
-    VALUES(
-        NEW.id
-    );
-
     UPDATE
         topics
     SET
@@ -44,13 +44,15 @@ BEGIN
         id = NEW.id
     ;
 
-    UPDATE
-        projects
-    SET
-        hub_id = id
-    WHERE
-        id = NEW.id
-    ;
+    INSERT INTO
+        hubs(
+            id,
+            location
+        )
+    VALUES(
+        NEW.id,
+        NEW.location
+    );
 
 
     INSERT INTO deltas(
@@ -64,33 +66,42 @@ BEGIN
         'new_hub'
     );
 
+    INSERT INTO topic_deltas(
+        id,
+        change_id,
+        topic_id
+    )
+    VALUES(
+        currval('deltas'),
+        NEW.change_id,
+        NEW.id
+    );
 
     INSERT INTO
         hub_deltas(
             id,
             change_id,
             hub_id,
-            new
+            new,
+            location
         )
     VALUES(
         currval('deltas'),
         NEW.change_id,
         NEW.id,
-        1
+        1,
+        NEW.location
     );
 
-
     INSERT INTO
-        bifkv(
-            key,
+        project_hubs(
+            project_id,
             hub_id
         )
-    SELECT
-        'local_hub',
+    VALUES(
+        NEW.id,
         NEW.id
-    WHERE
-        NEW.set_default
-    ;
+    );
 
     SELECT RAISE(IGNORE);
 END;
