@@ -1,21 +1,29 @@
-CREATE TABLE func_new_topic2(
+/*
+    This is an internal function that doesn't create its own
+    topic_delta, which is left up to whatever the calling function is.
+*/
+CREATE TABLE func_new_topic(
     change_id INTEGER,
     id INTEGER NOT NULL DEFAULT (nextval('topics')),
+    parent_id INTEGER,
     kind VARCHAR,
+    name VARCHAR NOT NULL,
     uuid VARCHAR(40)
 );
 
 
 CREATE TRIGGER
-    func_new_topic2_bi_1
+    func_new_topic_bi_1
 BEFORE INSERT ON
-    func_new_topic2
+    func_new_topic
 FOR EACH ROW
 BEGIN
 
     SELECT debug(
         NEW.change_id,
         NEW.id,
+        NEW.parent_id,
+        NEW.name,
         NEW.kind,
         NEW.uuid
     );
@@ -23,8 +31,11 @@ BEGIN
     INSERT INTO
         topics(
             id,
+            parent_id,
             first_change_id,
             last_change_id,
+            name,
+            path,
             kind,
             ctime,
             ctimetz,
@@ -35,8 +46,11 @@ BEGIN
         )
     SELECT
         NEW.id,
+        NEW.parent_id,
         NEW.change_id,
         NEW.change_id,
+        NEW.name,
+        NEW.kind || '-' || NEW.id, -- just to make the insertion unique
         NEW.kind,
         c.mtime,
         c.mtimetz,
