@@ -24,7 +24,7 @@ foreach my $method ( Log::Any::Adapter::Util::logging_methods() ) {
     no strict 'refs';
     my $method_level = Log::Any::Adapter::Util::numeric_level($method);
     *{$method} = sub {
-        my ( $self, $text ) = @_;
+        my $self = shift;
         return if $method_level > $self->{log_level};
         Test::More::diag( join( ' ', @_ ) );
     };
