@@ -56,7 +56,7 @@ sub run_in_tempdir (&) {
 
     {
         local $CWD = $tmp;
-        Test::More::note("\n$tmp");
+        Test::More::note("\nmkdir $tmp && cd $tmp");
         local $ENV{HOME} = $tmp;    # Don't use the testers HOME
         $sub->();
     }
@@ -64,7 +64,8 @@ sub run_in_tempdir (&) {
     return;
 }
 
-sub bif {
+sub _bif {
+    my $str = shift;
     my @bif = @_;
 
     my $stdout;
@@ -75,7 +76,7 @@ sub bif {
         open( STDOUT,  '>',  'stdout.txt' ) or die "open: $!";
     }
 
-    Test::More::note("bif @bif");
+    Test::More::note( sprintf( $str, "bif @bif" ) );
 
     my $result = eval {
         my ( $class, $opts ) = class_optargs( 'App::bif', @bif );
@@ -94,21 +95,28 @@ sub bif {
     return $result;
 }
 
+sub bif {
+    return _bif( '%s', @_ );
+}
+
 sub bif2 {
-    mkdir 'home2' unless -d 'home2';
+    if ( !-d 'home2' ) {
+        Test::More::note('mkdir home2');
+        mkdir 'home2';
+    }
     local $CWD = 'home2';
     local $ENV{HOME} = Path::Tiny->cwd;
-    return bif(@_);
+    return _bif( '(cd home2; HOME=. %s)', @_ );
 }
 
 sub hub {
-    local $CWD = 'hub.bif';
-    return bif(@_);
+    local $CWD = 'hub.bifhub';
+    return _bif( '(cd hub.bifhub; %s)', @_ );
 }
 
 sub hub2 {
-    local $CWD = 'hub2.bif';
-    return bif(@_);
+    local $CWD = 'hub2.bifhub';
+    return _bif( '(cd hub2.bifhub; %s)', @_ );
 }
 
 sub bifsync {
